@@ -31,13 +31,11 @@
 #include "kmymoneycategory.h"
 #include "kmymoneyaccountselector.h"
 #include "knewaccountdlg.h"
-#include "models.h"
 #include "accountsmodel.h"
 
 #include "dialogenums.h"
 #include "icons/icons.h"
 #include "mymoneyenums.h"
-#include "modelenums.h"
 
 using namespace Icons;
 
@@ -122,10 +120,8 @@ KAccountSelectDlg::KAccountSelectDlg(const eDialogs::Category accountType, const
     filterProxyModel->setHideEquityAccounts(true);
     filterProxyModel->addAccountGroup(accountTypes);
 
-    auto model = Models::instance()->accountsModel();
-    filterProxyModel->setSourceColumns(model->getColumns());
-    filterProxyModel->setSourceModel(model);
-    filterProxyModel->sort((int)eAccountsModel::Column::Account);
+    filterProxyModel->setSourceModel(MyMoneyFile::instance()->accountsModel());
+    filterProxyModel->sort(AccountsModel::Column::AccountName);
 
     d->ui->m_accountSelector->setModel(filterProxyModel);
 
@@ -164,8 +160,9 @@ void KAccountSelectDlg::slotCreateAccount()
 {
     Q_D(KAccountSelectDlg);
     if (!((int)d->m_accountType & ((int)eDialogs::Category::expense | (int)eDialogs::Category::income))) {
-        emit createAccount(d->m_account);
+        Q_EMIT createAccount(d->m_account);
         if (!d->m_account.id().isEmpty()) {
+            d->ui->m_accountSelector->setSelected(d->m_account.id());
             accept();
         }
     } else {
@@ -174,6 +171,7 @@ void KAccountSelectDlg::slotCreateAccount()
         else
             KNewAccountDlg::newCategory(d->m_account, MyMoneyFile::instance()->income());
         if (!d->m_account.id().isEmpty()) {
+            d->ui->m_accountSelector->setSelected(d->m_account.id());
             accept();
         }
     }
@@ -230,15 +228,5 @@ QString KAccountSelectDlg::selectedAccount() const
 {
     Q_D(const KAccountSelectDlg);
 
-    // in case an account was created before, it might not be in the
-    // account model (yet) due to the delayed update (an enclosing
-    // MyMoneyFileTransaction has not been committed). Therefor, we
-    // use the id of m_account which carries the id of the newly
-    // created account. If only an account was selected, the object
-    // m_account is empty.
-    if (d->m_account.id().isEmpty())
-        return d->ui->m_accountSelector->getSelected();
-    return d->m_account.id();
+    return d->ui->m_accountSelector->getSelected();
 }
-
-// kate: space-indent on; indent-width 2; remove-trailing-space on; remove-trailing-space-save on;
