@@ -7,6 +7,8 @@
 #ifndef KACCOUNTSELECTDLG_H
 #define KACCOUNTSELECTDLG_H
 
+#include "kmm_base_dialogs_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -30,7 +32,7 @@ enum Category : int;
 }
 
 class KAccountSelectDlgPrivate;
-class KAccountSelectDlg : public QDialog
+class KMM_BASE_DIALOGS_EXPORT KAccountSelectDlg : public QDialog
 {
     Q_OBJECT
     Q_DISABLE_COPY(KAccountSelectDlg)
