@@ -7,6 +7,8 @@
 #ifndef KAVAILABLECURRENCYDLG_H
 #define KAVAILABLECURRENCYDLG_H
 
+#include "kmm_base_dialogs_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -25,7 +27,7 @@ class KAvailableCurrencyDlg;
 
 class KTreeWidgetSearchLineWidget;
 class QTreeWidgetItem;
-class KAvailableCurrencyDlg : public QDialog
+class KMM_BASE_DIALOGS_EXPORT KAvailableCurrencyDlg : public QDialog
 {
     Q_OBJECT
 public:
