@@ -41,8 +41,8 @@ KMyMoneyFileInfoDlg::KMyMoneyFileInfoDlg(QWidget *parent) :
     // Now fill the fields with data
 
     const auto file = MyMoneyFile::instance();
-    ui->m_creationDate->setText(file->parametersModel()->itemById(file->fixedKey(MyMoneyFile::CreationDate)).value());
-    ui->m_lastModificationDate->setText(file->parametersModel()->itemById(file->fixedKey(MyMoneyFile::LastModificationDate)).value());
+    ui->m_creationDate->setText(file->fileInfoModel()->itemById(file->fixedKey(MyMoneyFile::CreationDate)).value());
+    ui->m_lastModificationDate->setText(file->fileInfoModel()->itemById(file->fixedKey(MyMoneyFile::LastModificationDate)).value());
     ui->m_baseCurrency->setText(file->baseCurrency().name());
 
     ui->m_payeeCount->setText(QString::fromLatin1("%1").arg(file->payeesModel()->rowCount()));
