@@ -8,6 +8,8 @@
 #ifndef KNEWACCOUNTDLG_H
 #define KNEWACCOUNTDLG_H
 
+#include "kmm_base_dialogs_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -26,7 +28,7 @@ class MyMoneyMoney;
 class MyMoneyAccount;
 
 class KNewAccountDlgPrivate;
-class KNewAccountDlg : public QDialog
+class KMM_BASE_DIALOGS_EXPORT KNewAccountDlg : public QDialog
 {
     Q_OBJECT
 
@@ -72,17 +74,33 @@ public:
     void addTab(QWidget* w, const QString& name);
 
     /**
-      * Brings up the new category editor and saves the information.
-      * The dialog will be preset with the name and parent account.
-      *
-      * @param account reference of category to be created. The @p name member
-      *                should be filled by the caller. The object will be filled
-      *                with additional information during the creation process
-      *                esp. the @p id member.
-      * @param parent reference to parent account (defaults to none)
-      */
+     * Brings up the new category editor and saves the information.
+     * The dialog will be preset with the name and parent account.
+     * In contrast to the createCategory() method, this method asks
+     * the user if he really wants to create the object.
+     *
+     * @param account reference of category to be created. The @p name member
+     *                should be filled by the caller. The object will be filled
+     *                with additional information during the creation process
+     *                esp. the @p id member.
+     * @param parent reference to parent account (defaults to none)
+     */
     static void newCategory(MyMoneyAccount& account, const MyMoneyAccount& parent);
 
+    /**
+     * Brings up the new account editor and saves the information.
+     * The dialog will be preset with the name and parent account.
+     * In contrast to the createAccount() method, this method asks
+     * the user if he really wants to create the object.
+     *
+     * @param account reference of account to be created. The @p name member
+     *                should be filled by the caller. The object will be filled
+     *                with additional information during the creation process
+     *                esp. the @p id member.
+     * @param parent reference to parent account (defaults to none)
+     */
+    static void newAccount(MyMoneyAccount& account, const MyMoneyAccount& parent);
+
     /**
      * This method opens the category editor with the data found in @a account. The
      * parent account is preset to @a parent but can be modified. If the user
@@ -90,6 +108,13 @@ public:
      */
     static void createCategory(MyMoneyAccount& account, const MyMoneyAccount& parent);
 
+    /**
+     * This method opens the account editor with the data found in @a account. The
+     * parent account is preset to @a parent but can be modified. If the user
+     * acknowledges, the account is created.
+     */
+    static void createAccount(MyMoneyAccount& account, const MyMoneyAccount& parent);
+
 protected Q_SLOTS:
     void okClicked();
     void slotSelectionChanged(const QItemSelection &current, const QItemSelection &previous);
@@ -99,10 +124,10 @@ protected Q_SLOTS:
     void slotNewClicked();
     void slotCheckFinished();
     void slotLoadInstitutions(const QString&);
-    void slotAdjustMinBalanceAbsoluteEdit(const QString&);
-    void slotAdjustMinBalanceEarlyEdit(const QString&);
-    void slotAdjustMaxCreditAbsoluteEdit(const QString&);
-    void slotAdjustMaxCreditEarlyEdit(const QString&);
+    void slotAdjustMinBalanceAbsoluteEdit();
+    void slotAdjustMinBalanceEarlyEdit();
+    void slotAdjustMaxCreditAbsoluteEdit();
+    void slotAdjustMaxCreditEarlyEdit();
     void slotCheckCurrency(int index);
 
 private:
