@@ -6,6 +6,8 @@
 #ifndef KSAVEASQUESTION_H
 #define KSAVEASQUESTION_H
 
+#include "kmm_base_dialogs_export.h"
+
 #include <QDialog>
 
 namespace Ui {
@@ -15,7 +17,7 @@ namespace eKMyMoney {
 enum class StorageType;
 }
 
-class KSaveAsQuestion : public QDialog
+class KMM_BASE_DIALOGS_EXPORT KSaveAsQuestion : public QDialog
 {
     Q_DISABLE_COPY(KSaveAsQuestion)
 
