@@ -28,16 +28,19 @@ public:
     explicit KSettingsGeneral(QWidget* parent = nullptr);
     ~KSettingsGeneral();
 
+public Q_SLOTS:
+    void setHideZeroBalanceAccountsHome(bool state);
+
 protected Q_SLOTS:
     void slotChooseLogPath();
-    void slotLoadStartDate(const QDate&);
     void slotUpdateLogTypes();
 
 protected:
     void showEvent(QShowEvent* event) override;
 
-public Q_SLOTS:
-    void slotUpdateEquitiesVisibility();
+Q_SIGNALS:
+    void haveValidInput(bool valid);
+    void hideZeroBalanceAccountsHomeChanged(bool state);
 
 private:
     KSettingsGeneralPrivate * const d_ptr;
