@@ -38,12 +38,12 @@ public:
     virtual ~StatementInterface();
 
     virtual void resetMessages() const = 0;
-    virtual void showMessages(int statementCount) const = 0;
+    virtual void showMessages() const = 0;
 
     /**
      * This method imports a MyMoneyStatement into the engine
      */
-    virtual QStringList import(const MyMoneyStatement& s, bool silent = false) = 0;
+    virtual bool import(const MyMoneyStatement& s) = 0;
 
     /**
      * This method returns the account for a given @a key - @a value pair.
