@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2023 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -8,6 +9,8 @@
 
 #include <QHashFunctions>
 
+#include "qhashseedtype.h"
+
 namespace eKMyMoney {
 enum class FileAction {
     Opened,
@@ -24,9 +27,9 @@ enum class StorageType {
     GNC,
 };
 
-inline uint qHash(const StorageType key, uint seed) {
+inline qHashSeedType qHash(const StorageType key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-
 }
 #endif
