@@ -6,7 +6,8 @@
 #include "onlinebankingaccountsfilterproxymodel.h"
 
 #include "mymoney/onlinejobadministration.h"
-#include "modelenums.h"
+#include "mymoneyenums.h"
+#include "accountsmodel.h"
 
 OnlineBankingAccountsFilterProxyModel::OnlineBankingAccountsFilterProxyModel(QObject* parent)
     : QSortFilterProxyModel(parent)
@@ -15,8 +16,8 @@ OnlineBankingAccountsFilterProxyModel::OnlineBankingAccountsFilterProxyModel(QOb
 
 bool OnlineBankingAccountsFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex& source_parent) const
 {
-    const QModelIndex sourceIndex = sourceModel()->index(source_row, (int)eAccountsModel::Column::Account, source_parent);
-    const QString accountId = sourceModel()->data(sourceIndex, (int)eAccountsModel::Role::ID).toString();
+    const QModelIndex sourceIndex = sourceModel()->index(source_row, AccountsModel::Column::AccountName, source_parent);
+    const QString accountId = sourceModel()->data(sourceIndex, eMyMoney::Model::Roles::IdRole).toString();
     if (accountId.isEmpty())
         return false;
     else if (onlineJobAdministration::instance()->isAnyJobSupported(accountId))
@@ -27,7 +28,7 @@ bool OnlineBankingAccountsFilterProxyModel::filterAcceptsRow(int source_row, con
 
 Qt::ItemFlags OnlineBankingAccountsFilterProxyModel::flags(const QModelIndex& index) const
 {
-    const QString accountId = sourceModel()->data(mapToSource(index), (int)eAccountsModel::Role::ID).toString();
+    const QString accountId = sourceModel()->data(mapToSource(index), eMyMoney::Model::Roles::IdRole).toString();
     if (onlineJobAdministration::instance()->isAnyJobSupported(accountId))
         return QSortFilterProxyModel::flags(index);
     return QSortFilterProxyModel::flags(index) & ~Qt::ItemIsSelectable;
@@ -39,8 +40,8 @@ bool OnlineBankingAccountsFilterProxyModel::filterAcceptsParent(const QModelInde
     auto const model = sourceModel();
     const auto rowCount = model->rowCount(index);
     for (auto i = 0; i < rowCount; ++i) {
-        const auto childIndex = model->index(i, (int)eAccountsModel::Column::Account, index); // CAUTION! Assumption is being made that Account column number is always 0
-        if (onlineJobAdministration::instance()->isAnyJobSupported(model->data(childIndex, (int)eAccountsModel::Role::ID).toString()))
+        const auto childIndex = model->index(i, AccountsModel::Column::AccountName, index); // CAUTION! Assumption is being made that Account column number is always 0
+        if (onlineJobAdministration::instance()->isAnyJobSupported(model->data(childIndex, eMyMoney::Model::Roles::IdRole).toString()))
             return true;
         if (filterAcceptsParent(childIndex))
             return true;
