@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2006 Ace Jones <acejones@users.sourceforge.net>
     SPDX-FileCopyrightText: 2006 Darren Gould <darren_gould@gmx.de>
+    SPDX-FileCopyrightText: 2010-2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -76,15 +77,16 @@ bool MyMoneyBudget::PeriodGroup::operator == (const PeriodGroup& right) const
 class MyMoneyBudget::AccountGroupPrivate {
 
 public:
-
-    AccountGroupPrivate() :
-        m_budgetlevel(eMyMoney::Budget::Level::None),
-        m_budgetsubaccounts(false)
+    AccountGroupPrivate()
+        : m_budgetlevel(eMyMoney::Budget::Level::None)
+        , m_budgetType(eMyMoney::Account::Type::Unknown)
+        , m_budgetsubaccounts(false)
     {
     }
 
     QString                                   m_id;
     eMyMoney::Budget::Level                   m_budgetlevel;
+    eMyMoney::Account::Type m_budgetType;
     bool                                      m_budgetsubaccounts;
     QMap<QDate, MyMoneyBudget::PeriodGroup>   m_periods;
 
@@ -211,6 +213,18 @@ void MyMoneyBudget::AccountGroup::setBudgetLevel(eMyMoney::Budget::Level level)
     d->m_budgetlevel = level;
 }
 
+eMyMoney::Account::Type MyMoneyBudget::AccountGroup::budgetType() const
+{
+    Q_D(const AccountGroup);
+    return d->m_budgetType;
+}
+
+void MyMoneyBudget::AccountGroup::setBudgetType(eMyMoney::Account::Type type)
+{
+    Q_D(AccountGroup);
+    d->m_budgetType = type;
+}
+
 MyMoneyBudget::PeriodGroup MyMoneyBudget::AccountGroup::period(const QDate& date) const
 {
     Q_D(const AccountGroup);
@@ -240,7 +254,7 @@ MyMoneyMoney MyMoneyBudget::AccountGroup::balance() const
     Q_D(const AccountGroup);
     MyMoneyMoney balance;
 
-    foreach (const auto period, d->m_periods)
+    for (const auto& period : d->m_periods)
         balance += period.amount();
     return balance;
 }
@@ -295,9 +309,9 @@ MyMoneyBudget::AccountGroup MyMoneyBudget::AccountGroup::operator += (const MyMo
     // in case the left side is empty, we add empty periods
     // so that both budgets are identical
     if (d->m_budgetlevel == eMyMoney::Budget::Level::None) {
-        it_pr = rPeriods.constBegin();
+        it_pr = rPeriods.cbegin();
         QDate date = (*it_pr).startDate();
-        while (it_pr != rPeriods.constEnd()) {
+        while (it_pr != rPeriods.cend()) {
             MyMoneyBudget::PeriodGroup period = *it_pr;
             period.setAmount(MyMoneyMoney());
             addPeriod(date, period);
@@ -313,12 +327,12 @@ MyMoneyBudget::AccountGroup MyMoneyBudget::AccountGroup::operator += (const MyMo
     // now both budgets should be of the same type and we simply need
     // to iterate over the period list and add the values
     d->m_periods.clear();
-    it_p = periods.constBegin();
-    it_pr = rPeriods.constBegin();
+    it_p = periods.cbegin();
+    it_pr = rPeriods.cbegin();
     QDate date = (*it_p).startDate();
-    while (it_p != periods.constEnd()) {
+    while (it_p != periods.cend()) {
         MyMoneyBudget::PeriodGroup period = *it_p;
-        if (it_pr != rPeriods.constEnd()) {
+        if (it_pr != rPeriods.cend()) {
             period.setAmount(period.amount() + (*it_pr).amount());
             ++it_pr;
         }
@@ -336,22 +350,21 @@ bool MyMoneyBudget::AccountGroup::operator == (const AccountGroup& right) const
     return (d->m_id == d2->m_id //
             && d->m_budgetlevel == d2->m_budgetlevel //
             && d->m_budgetsubaccounts == d2->m_budgetsubaccounts //
-            && d->m_periods.keys() == d2->m_periods.keys() //
-            && d->m_periods.values() == d2->m_periods.values());
+            && d->m_periods == d2->m_periods);
 }
 
 MyMoneyBudget::MyMoneyBudget() :
     MyMoneyObject(*new MyMoneyBudgetPrivate)
 {
     Q_D(MyMoneyBudget);
-    d->m_name = QLatin1Literal("Unconfigured Budget");
+    d->m_name = QStringLiteral("Unconfigured Budget");
 }
 
 MyMoneyBudget::MyMoneyBudget(const QString &id) :
     MyMoneyObject(*new MyMoneyBudgetPrivate, id)
 {
     Q_D(MyMoneyBudget);
-    d->m_name = QLatin1Literal("Unconfigured Budget");
+    d->m_name = QStringLiteral("Unconfigured Budget");
 }
 
 MyMoneyBudget::MyMoneyBudget(const QString& id, const MyMoneyBudget& other) :
@@ -375,36 +388,29 @@ bool MyMoneyBudget::operator == (const MyMoneyBudget& right) const
     // clang-format off
     return (MyMoneyObject::operator==(right)
             && (d->m_accounts.count() == d2->m_accounts.count())
-            && (d->m_accounts.keys() == d2->m_accounts.keys())
-            && (d->m_accounts.values() == d2->m_accounts.values())
+            && (d->m_accounts == d2->m_accounts)
             && (d->m_name == d2->m_name)
             && (d->m_start == d2->m_start));
     // clang-format on
 }
 
-bool MyMoneyBudget::hasReferenceTo(const QString& id) const
-{
-    Q_D(const MyMoneyBudget);
-    // return true if we have an assignment for this id
-    return (d->m_accounts.contains(id));
-}
-
 void MyMoneyBudget::removeReference(const QString& id)
 {
     Q_D(MyMoneyBudget);
     if (d->m_accounts.contains(id)) {
         d->m_accounts.remove(id);
     }
+    d->clearReferences();
 }
 
 const MyMoneyBudget::AccountGroup& MyMoneyBudget::account(const QString& id) const
 {
     static AccountGroup empty;
-    QMap<QString, AccountGroup>::ConstIterator it;
+    QMap<QString, AccountGroup>::const_iterator it;
 
     Q_D(const MyMoneyBudget);
     it = d->m_accounts.constFind(id);
-    if (it != d->m_accounts.constEnd())
+    if (it != d->m_accounts.cend())
         return it.value();
     return empty;
 }
@@ -421,6 +427,7 @@ void MyMoneyBudget::setAccount(const AccountGroup& account, const QString& id)
             acc.setId(id);
         d->m_accounts[id] = acc;
     }
+    d->clearReferences();
 }
 
 bool MyMoneyBudget::contains(const QString &id) const
