@@ -28,6 +28,11 @@
 class MyMoneyBudgetPrivate : public MyMoneyObjectPrivate
 {
 public:
+    void collectReferencedObjects() override
+    {
+        m_referencedObjects = m_accounts.keys();
+    }
+
     /**
       * The user-assigned name of the Budget
       */
