@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2012-2016 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2012-2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -9,6 +9,8 @@
 // QT Includes
 
 #include <QCollator>
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -21,6 +23,10 @@ MyMoneyCostCenter MyMoneyCostCenter::null;
 class MyMoneyCostCenterPrivate : public MyMoneyObjectPrivate
 {
 public:
+    void collectReferencedObjects() override
+    {
+    }
+
     QString m_name;
 };
 
@@ -64,11 +70,6 @@ bool MyMoneyCostCenter::operator < (const MyMoneyCostCenter& right) const
     return col.compare(d->m_name, d2->m_name);
 }
 
-bool MyMoneyCostCenter::hasReferenceTo(const QString& /*id*/) const
-{
-    return false;
-}
-
 QString MyMoneyCostCenter::name() const
 {
     Q_D(const MyMoneyCostCenter);
@@ -85,9 +86,10 @@ void MyMoneyCostCenter::setName(const QString& val)
 QString MyMoneyCostCenter::shortName() const
 {
     Q_D(const MyMoneyCostCenter);
-    QRegExp shortNumberExp("^(\\d+)\\s.+");
-    if(shortNumberExp.exactMatch(d->m_name)) {
-        return shortNumberExp.cap(1);
+    static const QRegularExpression shortNumberExp("^(\\d+)\\s.+");
+    const auto shortNumber(shortNumberExp.match(d->m_name));
+    if (shortNumber.hasMatch()) {
+        return shortNumber.captured(1);
     }
     return d->m_name;
 }
