@@ -310,6 +310,8 @@ enum class Date {
     LastFiscalYear,
     Today,
     Next18Months,
+    FiscalYearToDate,
+    FiscalMonthToDate,
     // insert new constants above of this line
     LastDateItem,
 };
@@ -562,7 +564,8 @@ enum Roles {
     AccountIsAssetLiabilityRole,
 
     // MyMoneyInstitution
-    InstitutionBankCodeRole,
+    InstitutionNameRole = AccountNameRole,
+    InstitutionBankCodeRole = AccountIsAssetLiabilityRole,
 
     // MyMoneyCostCenter
     CostCenterShortNameRole,
@@ -713,6 +716,15 @@ enum Roles {
     PricePairRole,
     PriceSourceRole,
 
+    // StatementModel
+    StatementTransactionCountRole,
+    StatementTransactionsAddedRole,
+    StatementTransactionsMatchedRole,
+    StatementTransactionDuplicatesRole,
+    StatementPayeesCreatedRole,
+    StatementBalanceRole,
+    StatementEndDateRole,
+
     // LedgerStack special roles
     ActiveFilterRole,
     ActiveFilterTextRole,
