@@ -13,8 +13,10 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
+#include <QRegularExpression>
 #include <QString>
 #include <QStringList>
+#include <QUrl>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -68,7 +70,9 @@ bool MyMoneyPayee::operator == (const MyMoneyPayee& right) const
             (d->m_matchKeyIgnoreCase == d2->m_matchKeyIgnoreCase) &&
             ((d->m_matchKey.length() == 0 && d2->m_matchKey.length() == 0) || d->m_matchKey == d2->m_matchKey) &&
             ((d->m_reference.length() == 0 && d2->m_reference.length() == 0) || (d->m_reference == d2->m_reference)) &&
-            ((d->m_defaultAccountId.length() == 0 && d2->m_defaultAccountId.length() == 0) || d->m_defaultAccountId == d2->m_defaultAccountId));
+            ((d->m_defaultAccountId.length() == 0 && d2->m_defaultAccountId.length() == 0) || d->m_defaultAccountId == d2->m_defaultAccountId)) &&
+            ((d->m_idPattern.length() == 0 && d2->m_idPattern.length() == 0) || (d->m_idPattern == d2->m_idPattern)) &&
+            ((d->m_urlTemplate.length() == 0 && d2->m_urlTemplate.length() == 0) || (d->m_urlTemplate == d2->m_urlTemplate));
 }
 
 bool MyMoneyPayee::operator < (const MyMoneyPayee& right) const
@@ -78,12 +82,6 @@ bool MyMoneyPayee::operator < (const MyMoneyPayee& right) const
     return d->m_name < d2->m_name;
 }
 
-bool MyMoneyPayee::hasReferenceTo(const QString& id) const
-{
-    Q_D(const MyMoneyPayee);
-    return id == d->m_defaultAccountId;
-}
-
 QString MyMoneyPayee::name() const
 {
     Q_D(const MyMoneyPayee);
@@ -227,9 +225,13 @@ eMyMoney::Payee::MatchType MyMoneyPayee::matchData(bool& ignorecase, QStringList
     if (d->m_matchingEnabled) {
         type = d->m_usingMatchKey ? eMyMoney::Payee::MatchType::Key : eMyMoney::Payee::MatchType::Name;
         if (type == eMyMoney::Payee::MatchType::Key) {
-            if (d->m_matchKey.contains(QLatin1Char('\n')))
+            if (d->m_matchKey.contains(QLatin1Char('\n'))) {
                 keys = d->m_matchKey.split(QLatin1Char('\n'));
-            else
+                // Since we added an empty string to the list to be able
+                // to differentiate between older and newer versions, we
+                // remove the empty list items here.
+                keys.removeAll(QString());
+            } else
                 keys = d->m_matchKey.split(QLatin1Char(';'));  // for compatibility with 4.8.0
         } else if (d->m_matchKey.compare(QLatin1String("^$")) == 0) {
             type = eMyMoney::Payee::MatchType::NameExact;
@@ -257,11 +259,16 @@ void MyMoneyPayee::setMatchData(eMyMoney::Payee::MatchType type, bool ignorecase
     if (d->m_matchingEnabled) {
         d->m_usingMatchKey = (type == eMyMoney::Payee::MatchType::Key);
         if (d->m_usingMatchKey) {
-            QRegExp validKeyRegExp("[^ ]");
-            QStringList filteredKeys = keys.filter(validKeyRegExp);
+            const QRegularExpression validKeyRegExp(QLatin1String("[^ ]"));
+            const auto filteredKeys = keys.filter(validKeyRegExp);
             d->m_matchKey = filteredKeys.join(QLatin1Char('\n'));
+            // we make sure that each matchKey contains at least a single \n.
+            // Otherwise, we are not able to have a single match that contains
+            // a semi-colon because that is treated as list separator in 4.8
+            if (filteredKeys.count() == 1) {
+                d->m_matchKey.append('\n');
+            }
         } else if ((type == eMyMoney::Payee::MatchType::Name) && (keys.count() == 1) && (keys.at(0) == QLatin1String("^$"))) {
-            type = eMyMoney::Payee::MatchType::NameExact;
             d->m_matchKey = QLatin1String("^$");
         } else if (type == eMyMoney::Payee::MatchType::NameExact) {
             d->m_matchKey = QLatin1String("^$");
@@ -287,6 +294,68 @@ void MyMoneyPayee::setDefaultAccountId(const QString& id)
 {
     Q_D(MyMoneyPayee);
     d->m_defaultAccountId = id;
+    d->clearReferences();
+}
+
+QString MyMoneyPayee::idPattern() const
+{
+    Q_D(const MyMoneyPayee);
+    return d->m_idPattern;
+}
+
+void MyMoneyPayee::setIdPattern(const QString& idPattern)
+{
+    Q_D(MyMoneyPayee);
+    d->m_idPattern = idPattern;
+    if (idPattern.contains(QStringLiteral("(")))
+        d->m_idPatternRegEx.setPattern(idPattern);
+    else
+        d->m_idPatternRegEx.setPattern(QStringLiteral("(%1)").arg(idPattern));
+}
+
+QString MyMoneyPayee::urlTemplate() const
+{
+    Q_D(const MyMoneyPayee);
+    return d->m_urlTemplate;
+}
+
+void MyMoneyPayee::setUrlTemplate(const QString& urlTemplate)
+{
+    Q_D(MyMoneyPayee);
+    d->m_urlTemplate = urlTemplate;
+}
+
+QUrl MyMoneyPayee::payeeLink(const QString& text) const
+{
+    QStringList matches = matchingLinks(text);
+    if (matches.size() == 2) {
+        return QUrl(urlTemplate().arg(matches[1]));
+    } else if (matches.size() == 3) {
+        return QUrl(urlTemplate().arg(matches[1], matches[2]));
+    } else {
+        return QUrl();
+    }
+}
+
+QString MyMoneyPayee::decorateLink(const QString& text) const
+{
+    QStringList matches = matchingLinks(text);
+    if (matches.size() == 0 || matches[0].isEmpty())
+        return text;
+    QRegularExpression rx(QStringLiteral("(%1)").arg(matches[0]));
+
+    QString result = text;
+    result.replace(rx, QStringLiteral("<\\1>"));
+    return result;
+}
+
+QStringList MyMoneyPayee::matchingLinks(const QString& text) const
+{
+    Q_D(const MyMoneyPayee);
+    QRegularExpressionMatch match = d->m_idPatternRegEx.match(text);
+    if (!match.hasMatch())
+        return QStringList();
+    return match.capturedTexts();
 }
 
 // vim:cin:si:ai:et:ts=2:sw=2:
