@@ -2,6 +2,7 @@
     SPDX-FileCopyrightText: 2004-2006 Ace Jones <acejones@users.sourceforge.net>
     SPDX-FileCopyrightText: 2006 Darren Gould <darren_gould@gmx.de>
     SPDX-FileCopyrightText: 2007-2010 Alvaro Soliverez <asoliverez@gmail.com>
+    SPDX-FileCopyrightText: 2010-2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2017-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-FileCopyrightText: 2018 Michael Kiefer <Michael-Kiefer@web.de>
     SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,20 +19,21 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "mymoneymoney.h"
-#include "mymoneyfile.h"
+#include "journalmodel.h"
 #include "mymoneyaccount.h"
+#include "mymoneyexception.h"
+#include "mymoneyfile.h"
+#include "mymoneymoney.h"
 #include "mymoneytransaction.h"
 #include "mymoneytransactionfilter.h"
-#include "mymoneyexception.h"
 
-MyMoneyReport::MyMoneyReport() :
-    MyMoneyObject(*new MyMoneyReportPrivate)
+MyMoneyReport::MyMoneyReport()
+    : MyMoneyObject(*new MyMoneyReportPrivate(this))
 {
 }
 
-MyMoneyReport::MyMoneyReport(const QString &id) :
-    MyMoneyObject(*new MyMoneyReportPrivate, id)
+MyMoneyReport::MyMoneyReport(const QString& id)
+    : MyMoneyObject(*new MyMoneyReportPrivate(this), id)
 {
 }
 
@@ -40,8 +42,8 @@ MyMoneyReport::MyMoneyReport(eMyMoney::Report::RowType rt,
                              eMyMoney::TransactionFilter::Date dl,
                              eMyMoney::Report::DetailLevel ss,
                              const QString& name,
-                             const QString& comment) :
-    MyMoneyObject(*new MyMoneyReportPrivate)
+                             const QString& comment)
+    : MyMoneyObject(*new MyMoneyReportPrivate(this))
 {
     Q_D(MyMoneyReport);
     d->m_name = name;
@@ -79,7 +81,7 @@ MyMoneyReport::MyMoneyReport(eMyMoney::Report::RowType rt,
 #ifdef DEBUG_REPORTS
     QDebug out = qDebug();
     out << _name << toString(_rt) << toString(m_reportType);
-    foreach(const eMyMoney::Account::Type accountType, m_accountGroups)
+    for (const eMyMoney::Account::Type& accountType : m_accountGroups)
         out << MyMoneyeMyMoney::Account::accountTypeToString(accountType);
     if (m_accounts.size() > 0)
         out << m_accounts;
@@ -317,6 +319,18 @@ void MyMoneyReport::setTax(bool f)
     d->m_tax = f;
 }
 
+bool MyMoneyReport::isPropagateBudgetDifference() const
+{
+    Q_D(const MyMoneyReport);
+    return d->m_propagateBudgetDifference;
+}
+
+void MyMoneyReport::setPropagateBudgetDifference(bool f)
+{
+    Q_D(MyMoneyReport);
+    d->m_propagateBudgetDifference = f;
+}
+
 bool MyMoneyReport::isInvestmentsOnly() const
 {
     Q_D(const MyMoneyReport);
@@ -755,7 +769,9 @@ void MyMoneyReport::setDateFilter(const QDate& db, const QDate& de)
 void MyMoneyReport::updateDateFilter()
 {
     Q_D(MyMoneyReport);
-    if (d->m_dateLock != eMyMoney::TransactionFilter::Date::UserDefined) MyMoneyTransactionFilter::setDateFilter(d->m_dateLock);
+    if (d->m_dateLock != eMyMoney::TransactionFilter::Date::UserDefined) {
+        MyMoneyTransactionFilter::setDateFilter(d->m_dateLock);
+    }
 }
 
 
@@ -831,6 +847,12 @@ void MyMoneyReport::setSkipZero(int f)
     d->m_skipZero = f;
 }
 
+bool MyMoneyReport::isNetWortReport() const
+{
+    Q_D(const MyMoneyReport);
+    return d->m_group == QLatin1String("Net Worth");
+}
+
 void MyMoneyReport::clearTransactionFilter()
 {
     Q_D(MyMoneyReport);
@@ -861,21 +883,11 @@ void MyMoneyReport::validDateRange(QDate& db, QDate& de)
     // year as the filter criteria.
 
     if (!db.isValid() || !de.isValid()) {
-        QList<MyMoneyTransaction> list = MyMoneyFile::instance()->transactionList(*this);
-        QDate tmpBegin, tmpEnd;
+        const auto dateRange = MyMoneyFile::instance()->journalModel()->dateRange();
+        auto tmpBegin = dateRange.firstTransaction;
+        auto tmpEnd = dateRange.lastTransaction;
 
-        if (!list.isEmpty()) {
-            qSort(list);
-            // try to use the post dates
-            tmpBegin = list.front().postDate();
-            tmpEnd = list.back().postDate();
-            // if the post dates are not valid try the entry dates
-            if (!tmpBegin.isValid())
-                tmpBegin = list.front().entryDate();
-            if (!tmpEnd.isValid())
-                tmpEnd = list.back().entryDate();
-        }
-        // make sure that we leave this function with valid dates no mather what
+        // make sure that we leave this function with valid dates no matter what
         if (!tmpBegin.isValid() || !tmpEnd.isValid() || tmpBegin > tmpEnd) {
             tmpBegin = QDate(QDate::currentDate().year(), 1, 1);   // the first date in the file
             tmpEnd = QDate(QDate::currentDate().year(), 12, 31);   // the last date in the file
@@ -931,12 +943,21 @@ bool MyMoneyReport::includes(const MyMoneyAccount& acc) const
     Q_D(const MyMoneyReport);
     auto result = false;
 
+    // Usually, budget reports only contain income and expense accounts
+    // but asset and liability accounts can also count as income or expense
+    // account in a budget. In this case, we need to include them. Such accounts
+    // are identified by the fact that their budgetAccountType differs from
+    // their accountType.
+    if (hasBudget()) {
+        result = acc.budgetAccountType() != acc.accountType();
+    }
+
     if (includesAccountGroup(acc.accountGroup())) {
         switch (acc.accountGroup()) {
         case eMyMoney::Account::Type::Income:
         case eMyMoney::Account::Type::Expense:
             if (isTax())
-                result = (acc.value("Tax") == "Yes") && includesCategory(acc.id());
+                result = acc.isInTaxReports() && includesCategory(acc.id());
             else
                 result = includesCategory(acc.id());
             break;
@@ -964,19 +985,6 @@ bool MyMoneyReport::includes(const MyMoneyAccount& acc) const
     return result;
 }
 
-bool MyMoneyReport::hasReferenceTo(const QString& id) const
-{
-    QStringList list;
-
-    // collect all ids
-    accounts(list);
-    categories(list);
-    payees(list);
-    tags(list);
-
-    return list.contains(id);
-}
-
 int MyMoneyReport::m_lineWidth = 2;
 bool MyMoneyReport::m_expertMode = false;
 
