@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2005-2017 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2005-2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2017-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,6 +15,7 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
 
 // ----------------------------------------------------------------------------
@@ -223,12 +224,6 @@ void MyMoneySecurity::setPricePrecision(const int pp)
     d->m_pricePrecision = pp;
 }
 
-bool MyMoneySecurity::hasReferenceTo(const QString& id) const
-{
-    Q_D(const MyMoneySecurity);
-    return (id == d->m_tradingCurrency);
-}
-
 QString MyMoneySecurity::securityTypeToString(const eMyMoney::Security::Type securityType)
 {
     switch (securityType) {
@@ -251,22 +246,22 @@ QString MyMoneySecurity::roundingMethodToString(const AlkValue::RoundingMethod r
 {
     switch (roundingMethod) {
     case AlkValue::RoundNever:
-        return I18N_NOOP("Never");
+        return kli18n("Never").untranslatedText();
     case AlkValue::RoundFloor:
-        return I18N_NOOP("Floor");
+        return kli18n("Floor").untranslatedText();
     case AlkValue::RoundCeil:
-        return I18N_NOOP("Ceil");
+        return kli18n("Ceil").untranslatedText();
     case AlkValue::RoundTruncate:
-        return I18N_NOOP("Truncate");
+        return kli18n("Truncate").untranslatedText();
     case AlkValue::RoundPromote:
-        return I18N_NOOP("Promote");
+        return kli18n("Promote").untranslatedText();
     case AlkValue::RoundHalfDown:
-        return I18N_NOOP("HalfDown");
+        return kli18n("HalfDown").untranslatedText();
     case AlkValue::RoundHalfUp:
-        return I18N_NOOP("HalfUp");
+        return kli18n("HalfUp").untranslatedText();
     case AlkValue::RoundRound:
-        return I18N_NOOP("Round");
+        return kli18n("Round").untranslatedText();
     default:
-        return I18N_NOOP("Unknown");
+        return kli18n("Unknown").untranslatedText();
     }
 }
