@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2012 Alessandro Russo <axela74@yahoo.it>
     SPDX-FileCopyrightText: 2017-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -119,8 +120,3 @@ bool MyMoneyTag::operator < (const MyMoneyTag& right) const
     auto d2 = static_cast<const MyMoneyTagPrivate *>(right.d_func());
     return d->m_name < d2->m_name;
 }
-
-bool MyMoneyTag::hasReferenceTo(const QString& /*id*/) const
-{
-    return false;
-}
