@@ -22,18 +22,22 @@
 class MyMoneyTagPrivate : public MyMoneyObjectPrivate
 {
 public:
-
-    MyMoneyTagPrivate() :
-        m_closed(false),
-        m_tag_color(QColor("black"))
+    MyMoneyTagPrivate()
+        : m_closed(false)
+        , m_tag_color(QColor("black"))
     {
     }
 
-    MyMoneyTagPrivate(const MyMoneyTagPrivate& d) :
-        m_name(d.m_name),
-        m_closed(d.m_closed),
-        m_tag_color(d.m_tag_color),
-        m_notes(d.m_notes)
+    MyMoneyTagPrivate(const MyMoneyTagPrivate& d)
+        : MyMoneyObjectPrivate(d)
+        , m_name(d.m_name)
+        , m_closed(d.m_closed)
+        , m_tag_color(d.m_tag_color)
+        , m_notes(d.m_notes)
+    {
+    }
+
+    void collectReferencedObjects() override
     {
     }
 
