@@ -7,11 +7,19 @@
 #include "mymoneytracer.h"
 
 #include <iostream>
-
 #include <cstdio>
 #include <cstdarg>
 
-#include <QRegExp>
+// ----------------------------------------------------------------------------
+// QT Includes
+
+#include <QRegularExpression>
+
+// ----------------------------------------------------------------------------
+// KDE Includes
+
+// ----------------------------------------------------------------------------
+// Project Includes
 
 class MyMoneyTracerPrivate
 {
@@ -35,12 +43,14 @@ int MyMoneyTracerPrivate::m_onoff = 0;
 MyMoneyTracer::MyMoneyTracer(const char* name) :
     d_ptr(new MyMoneyTracerPrivate)
 {
+    static const QRegularExpression classMethodExp("(.*)::(.*)");
+
     Q_D(MyMoneyTracer);
     if (d->m_onoff) {
-        QRegExp exp("(.*)::(.*)");
-        if (exp.indexIn(name) != -1) {
-            d->m_className = exp.cap(1);
-            d->m_memberName = exp.cap(2);
+        const auto classAndMethod(classMethodExp.match(name));
+        if (classAndMethod.hasMatch()) {
+            d->m_className = classAndMethod.captured(1);
+            d->m_memberName = classAndMethod.captured(2);
         } else {
             d->m_className = QString(name);
             d->m_memberName.clear();
