@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2013-2015 Christian Dávid <christian-david@web.de>
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -12,65 +13,48 @@
 #include "tasks/onlinetask.h"
 #include "onlinejobadministration.h"
 
-onlineJob::onlineJob() :
-    MyMoneyObject(*new onlineJobPrivate),
-    m_task(0)
-{
-    Q_D(onlineJob);
-    d->m_jobSend = QDateTime();
-    d->m_jobBankAnswerDate = QDateTime();
-    d->m_jobBankAnswerState = eMyMoney::OnlineJob::sendingState::noBankAnswer;
-    d->m_messageList = QList<onlineJobMessage>();
-    d->m_locked = false;
-}
-
-onlineJob::onlineJob(const QString &id) :
-    MyMoneyObject(*new onlineJobPrivate, id),
-    m_task(nullptr)
+onlineJob::onlineJob()
+    : MyMoneyObject(*new onlineJobPrivate(this))
+    , m_task(nullptr)
 {
 }
 
-onlineJob::onlineJob(onlineTask* onlinetask, const QString &id) :
-    MyMoneyObject(*new onlineJobPrivate, id),
-    m_task(onlinetask)
+onlineJob::onlineJob(const QString& id)
+    : MyMoneyObject(*new onlineJobPrivate(this), id)
+    , m_task(nullptr)
 {
-    Q_D(onlineJob);
-    d->m_jobSend = QDateTime();
-    d->m_jobBankAnswerDate = QDateTime();
-    d->m_jobBankAnswerState = eMyMoney::OnlineJob::sendingState::noBankAnswer;
-    d->m_messageList = QList<onlineJobMessage>();
-    d->m_locked = false;
 }
 
-onlineJob::onlineJob(onlineTask* onlinetask) :
-    MyMoneyObject(*new onlineJobPrivate, QString()),
-    m_task(onlinetask)
+onlineJob::onlineJob(onlineTask* onlinetask, const QString& id)
+    : MyMoneyObject(*new onlineJobPrivate(this), id)
+    , m_task(onlinetask)
 {
-    Q_D(onlineJob);
-    d->m_jobSend = QDateTime();
-    d->m_jobBankAnswerDate = QDateTime();
-    d->m_jobBankAnswerState = eMyMoney::OnlineJob::sendingState::noBankAnswer;
-    d->m_messageList = QList<onlineJobMessage>();
-    d->m_locked = false;
 }
 
-onlineJob::onlineJob(onlineJob const& other) :
-    MyMoneyObject(*new onlineJobPrivate(*other.d_func()), other.id()),
-    m_task(0)
+onlineJob::onlineJob(onlineTask* onlinetask)
+    : MyMoneyObject(*new onlineJobPrivate(this), QString())
+    , m_task(onlinetask)
+{
+}
+
+onlineJob::onlineJob(onlineJob const& other)
+    : MyMoneyObject(*new onlineJobPrivate(this, *other.d_func()), other.id())
+    , m_task(nullptr)
 {
     copyPointerFromOtherJob(other);
 }
 
-onlineJob::onlineJob(const QString &id, const onlineJob& other) :
-    MyMoneyObject(*new onlineJobPrivate(*other.d_func()), id),
-    m_task()
+onlineJob::onlineJob(const QString& id, const onlineJob& other)
+    : MyMoneyObject(*new onlineJobPrivate(this, *other.d_func()), id)
+    , m_task(nullptr)
 {
     Q_D(onlineJob);
+    d->m_jobBankAnswerState = eMyMoney::OnlineJob::sendingState::noBankAnswer;
+    d->m_locked = false;
     d->m_jobSend = QDateTime();
     d->m_jobBankAnswerDate = QDateTime();
-    d->m_jobBankAnswerState = eMyMoney::OnlineJob::sendingState::noBankAnswer;
-    d->m_messageList = QList<onlineJobMessage>();
-    d->m_locked = false;
+    d->m_messageList.clear();
+
     copyPointerFromOtherJob(other);
 }
 
@@ -97,19 +81,24 @@ onlineJob::~onlineJob()
 
 void onlineJob::setTask(onlineTask *_task)
 {
+    Q_D(onlineJob);
     m_task = _task;
+    d->clearReferences();
+    if (m_task) {
+        d->m_referencedObjects = m_task->referencedObjects();
+    }
 }
 
 onlineTask* onlineJob::task()
 {
-    if (m_task == 0)
+    if (m_task == nullptr)
         throw EMPTYTASKEXCEPTION;
     return m_task;
 }
 
 const onlineTask* onlineJob::task() const
 {
-    if (m_task == 0)
+    if (m_task == nullptr)
         throw EMPTYTASKEXCEPTION;
     return m_task;
 }
@@ -129,6 +118,15 @@ QString onlineJob::taskIid() const
     return QString();
 }
 
+QString onlineJob::purpose() const
+{
+    try {
+        return task()->purpose();
+    } catch (const emptyTask&) {
+    }
+    return QString();
+}
+
 QString onlineJob::responsibleAccount() const
 {
     try {
@@ -168,7 +166,7 @@ bool onlineJob::isEditable() const
 
 bool onlineJob::isNull() const
 {
-    return (m_task == 0);
+    return (m_task == nullptr);
 }
 
 void onlineJob::setJobSend(const QDateTime &dateTime)
@@ -240,12 +238,12 @@ QList<onlineJobMessage> onlineJob::jobMessageList() const
 void onlineJob::clearJobMessageList()
 {
     Q_D(onlineJob);
-    d->m_messageList = QList<onlineJobMessage>();
+    d->m_messageList.clear();
 }
 
 bool onlineJob::isValid() const
 {
-    if (m_task != 0)
+    if (m_task != nullptr)
         return m_task->isValid();
     return false;
 }
@@ -255,10 +253,3 @@ QDateTime onlineJob::sendDate() const
     Q_D(const onlineJob);
     return d->m_jobSend;
 }
-
-bool onlineJob::hasReferenceTo(const QString& id) const
-{
-    if (m_task != 0)
-        return m_task->hasReferenceTo(id);
-    return false;
-}
