@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2013-2016 Christian Dávid <christian-david@web.de>
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -62,6 +63,11 @@ public:
 
     virtual bool hasReferenceTo(const QString& id) const override = 0;
 
+    /**
+     * @copydoc MyMoneyObject::referencedObjects
+     */
+    virtual KMMStringSet referencedObjects() const override = 0;
+
     class settings : public IonlineTaskSettings
     {
     public:
@@ -109,13 +115,10 @@ public:
 
     virtual QSharedPointer<const settings> getSettings() const = 0;
 
-    virtual void writeXML(QDomDocument& document, QDomElement& parent) const override = 0;
-
 protected:
     virtual sepaOnlineTransfer* clone() const override = 0;
 
-    virtual sepaOnlineTransfer* createFromXml(const QDomElement &element) const override = 0;
-
+    virtual sepaOnlineTransfer* createFromXml(QXmlStreamReader* reader) const override = 0;
 };
 
 #endif // SEPAONLINETRANSFER_H
