@@ -1,13 +1,13 @@
 /*
+
     SPDX-FileCopyrightText: 2014 Christian Dávid <christian-david@web.de>
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef UNAVAILABLETASK_H
 #define UNAVAILABLETASK_H
 
-#include <QDomElement>
-
 #include "onlinetasks/interfaces/tasks/onlinetask.h"
 
 /**
@@ -25,20 +25,29 @@ public:
     bool isValid() const override;
     QString jobTypeName() const override;
 
-    void writeXML(QDomDocument& document, QDomElement& parent) const override;
+    void writeXML(QXmlStreamWriter* writer) const override;
+
 protected:
     QString responsibleAccount() const override;
-    unavailableTask* createFromXml(const QDomElement& element) const override;
+    QString purpose() const override;
+    unavailableTask* createFromXml(QXmlStreamReader* reader) const override;
+
     bool hasReferenceTo(const QString& id) const override;
+
+    /**
+     * @copydoc MyMoneyObject::referencedObjects
+     */
+    KMMStringSet referencedObjects() const override;
+
     unavailableTask* clone() const override;
 
 private:
-    explicit unavailableTask(const QDomElement& element);
+    explicit unavailableTask(const QString& xmlData);
 
     /**
      * The data received by createFromXml(). Written back by writeXML().
      */
-    QDomElement m_data;
+    QString m_data;
 };
 
 #endif // UNAVAILABLETASK_H
