@@ -9,9 +9,11 @@
 
 #include <QObject>
 
+#include "mymoneytestutils.h"
+
 class MyMoneyAccount;
 
-class MyMoneyAccountTest : public QObject
+class MyMoneyAccountTest : public QObject, public MyMoneyTestBase
 {
     Q_OBJECT
 
@@ -41,6 +43,8 @@ private Q_SLOTS:
     void testBalanceFactor_data();
     void testPayeeCreation();
     void testPayeeCreation_data();
+    void testPriceMode();
+    void testPriceMode_data();
 };
 
 #endif
