@@ -32,17 +32,13 @@ QTEST_GUILESS_MAIN(MyMoneyForecastTest)
 MyMoneyForecastTest::MyMoneyForecastTest() :
     m(nullptr),
     storage(nullptr),
-    file(nullptr)
+    file(nullptr),
+    moT1(57, 1),
+    moT2(63, 1),
+    moT3(84, 1),
+    moT4(62, 1),
+    moT5(104, 1)
 {
-    try {
-        this->moT1 = MyMoneyMoney(57, 1);
-        this->moT2 = MyMoneyMoney(63, 1);
-        this->moT3 = MyMoneyMoney(84, 1);
-        this->moT4 = MyMoneyMoney(62, 1);
-        this->moT5 = MyMoneyMoney(104, 1);
-    } catch (const MyMoneyException &e) {
-        qDebug() << e.what();
-    }
 }
 
 void MyMoneyForecastTest::init()
@@ -50,9 +46,8 @@ void MyMoneyForecastTest::init()
 
     //all this has been taken from pivottabletest.cpp, by Thomas Baumgart and Ace Jones
 
-    storage = new MyMoneyStorageMgr;
     file = MyMoneyFile::instance();
-    file->attachStorage(storage);
+    file->unload();
 
     MyMoneyFileTransaction ft;
     file->addCurrency(MyMoneySecurity("CAD", "Canadian Dollar",        "C$"));
@@ -97,8 +92,6 @@ void MyMoneyForecastTest::init()
 
 void MyMoneyForecastTest::cleanup()
 {
-    file->detachStorage(storage);
-    delete storage;
 }
 
 void MyMoneyForecastTest::testEmptyConstructor()
@@ -787,7 +780,6 @@ void MyMoneyForecastTest::testBeginForecastDate()
 
     //setup begin day to same date
     a.setBeginForecastDay(QDate::currentDate().day());
-    beginDay = a.beginForecastDay();
     a.doForecast();
 
     QVERIFY(QDate::currentDate() == a.beginForecastDate());
@@ -958,7 +950,7 @@ void MyMoneyForecastTest::testCreateBudget()
     MyMoneyMoney c_parent = c.forecastBalance(a_parent, QDate(QDate::currentDate().addMonths(1).year(), QDate::currentDate().addMonths(1).month(), 1));
 
     //test valid results
-    QVERIFY(c.forecastBalance(a_parent, QDate(QDate::currentDate().addMonths(1).year(), QDate::currentDate().addMonths(1).month(), 1)) == (moT2));
+    QCOMPARE(c.forecastBalance(a_parent, QDate(QDate::currentDate().addMonths(1).year(), QDate::currentDate().addMonths(1).month(), 1)).formatMoney(4), moT2.formatMoney(4));
 }
 
 void MyMoneyForecastTest::testLinearRegression()
