@@ -13,9 +13,11 @@
 #define KMM_MYMONEY_UNIT_TESTABLE friend class MyMoneyMoneyTest;
 
 #include <config-kmymoney.h>
+
+#include "mymoneyenums.h"
 #include "mymoneyexception.h"
 #include "mymoneymoney.h"
-#include "mymoneyenums.h"
+#include "mymoneysecurity.h"
 
 QTEST_GUILESS_MAIN(MyMoneyMoneyTest)
 
@@ -487,6 +489,15 @@ void MyMoneyMoneyTest::testFormatMoney()
     QCOMPARE(m1.formatMoney("", -1), QStringLiteral("-14.04"));
 }
 
+void MyMoneyMoneyTest::testBug491828()
+{
+    // test to cover bug #491828
+    int precision(8);
+    MyMoneySecurity bitcoin("BTC", QLatin1String("Bitcoin"), "BTC", 100000000, 100000000);
+    MyMoneyMoney smallestFraction = MyMoneyMoney::ONE / MyMoneyMoney(bitcoin.smallestCashFraction());
+    QCOMPARE(smallestFraction.formatMoney(QString(), precision), QStringLiteral("0.00000001"));
+}
+
 void MyMoneyMoneyTest::testRelation()
 {
     MyMoneyMoney m1(100, 100);
@@ -744,3 +755,18 @@ void MyMoneyMoneyTest::testMaxPrecision()
     QCOMPARE(m1.toString(), QStringLiteral("112345678921234567893123/100000000000000000000000"));
     QCOMPARE(m1.formatMoney("", -1), QStringLiteral("1.12345678921234567893"));
 }
+
+void MyMoneyMoneyTest::testZeroIsMinusZero()
+{
+    MyMoneyMoney m1;
+    QCOMPARE(m1.isZero(), true);
+    m1 = -m1;
+    QCOMPARE(m1.isZero(), true);
+}
+
+void MyMoneyMoneyTest::testAutoCalcDetection()
+{
+    MyMoneyMoney calc = MyMoneyMoney::autoCalc;
+    QVERIFY(calc.isAutoCalc());
+    QVERIFY((-calc).isAutoCalc());
+}
