@@ -6,19 +6,19 @@
 
 #include "mymoneytransactionfilter-test.h"
 
+#include <QRegularExpression>
 #include <QTest>
 
-#include "mymoneyenums.h"
-#include "mymoneytransactionfilter.h"
-#include "mymoneyfile.h"
-#include "mymoneystoragemgr.h"
 #include "mymoneyaccount.h"
+#include "mymoneyenums.h"
+#include "mymoneyexception.h"
+#include "mymoneyfile.h"
 #include "mymoneypayee.h"
 #include "mymoneysecurity.h"
+#include "mymoneysplit.h"
 #include "mymoneytag.h"
 #include "mymoneytransaction.h"
-#include "mymoneysplit.h"
-#include "mymoneyexception.h"
+#include "mymoneytransactionfilter.h"
 
 // uses helper functions from reports tests
 #include "tests/testutilities.h"
@@ -29,16 +29,13 @@ QTEST_GUILESS_MAIN(MyMoneyTransactionFilterTest)
 
 
 MyMoneyTransactionFilterTest::MyMoneyTransactionFilterTest::MyMoneyTransactionFilterTest()
-    : storage(nullptr)
-    , file(nullptr)
+    : file(nullptr)
 {
 }
 
 void MyMoneyTransactionFilterTest::init()
 {
-    storage = new MyMoneyStorageMgr;
     file = MyMoneyFile::instance();
-    file->attachStorage(storage);
 
     MyMoneyFileTransaction ft;
     file->addCurrency(MyMoneySecurity("USD", "US Dollar", "$"));
@@ -52,20 +49,18 @@ void MyMoneyTransactionFilterTest::init()
     file->addTag(tag);
     tagIdList << tag.id();
 
-    QString acAsset = MyMoneyFile::instance()->asset().id();
-    QString acExpense = (MyMoneyFile::instance()->expense().id());
-    QString acIncome = (MyMoneyFile::instance()->income().id());
-    acCheckingId = makeAccount("Account 10.2", eMyMoney::Account::Type::Checkings, MyMoneyMoney(0.0), QDate(2004, 1, 1), acAsset);
-    acExpenseId = makeAccount("Expense", eMyMoney::Account::Type::Expense, MyMoneyMoney(), QDate(2004, 1, 11), acExpense);
-    acIncomeId = makeAccount("Expense", eMyMoney::Account::Type::Expense, MyMoneyMoney(), QDate(2004, 1, 11), acIncome);
+    const QString asset = MyMoneyFile::instance()->asset().id();
+    const QString expense = (MyMoneyFile::instance()->expense().id());
+    const QString income = (MyMoneyFile::instance()->income().id());
+    acCheckingId = makeAccount(QLatin1String("Account 10.2"), eMyMoney::Account::Type::Checkings, MyMoneyMoney(0.0), QDate(2004, 1, 1), asset);
+    acExpenseId = makeAccount(QLatin1String("Expense"), eMyMoney::Account::Type::Expense, MyMoneyMoney(), QDate(2004, 1, 11), expense);
+    acIncomeId = makeAccount(QLatin1String("Expense"), eMyMoney::Account::Type::Expense, MyMoneyMoney(), QDate(2004, 1, 11), income);
 
     ft.commit();
 }
 
 void MyMoneyTransactionFilterTest::cleanup()
 {
-    file->detachStorage(storage);
-    delete storage;
 }
 
 void MyMoneyTransactionFilterTest::testMatchAmount()
@@ -90,12 +85,11 @@ void MyMoneyTransactionFilterTest::testMatchText()
 
     // no filter
     QCOMPARE(filter.matchText(split, account), true);
-
-    filter.setTextFilter(QRegExp("10.2"), false);
+    filter.setTextFilter(QRegularExpression("10.2"), false, false);
     MyMoneyTransactionFilter filterInvert;
-    filterInvert.setTextFilter(QRegExp("10.2"), true);
+    filterInvert.setTextFilter(QRegularExpression("10.2"), false, true);
     MyMoneyTransactionFilter filterNotFound;
-    filterNotFound.setTextFilter(QRegExp("10.5"), false);
+    filterNotFound.setTextFilter(QRegularExpression("10.5"), false, false);
 
     // memo
     split.setMemo("10.2");
@@ -509,7 +503,7 @@ void MyMoneyTransactionFilterTest::testMatchTransactionTag()
     QVERIFY(filter.match(transaction));
     QCOMPARE(filter.matchingSplits(transaction).size(), 1);
 
-    // check disabled category splits support
+    // check no category support
     MyMoneySplit split4;
     split4.setAccountId(acExpenseId);
     split4.setShares(MyMoneyMoney(123.00));
@@ -523,10 +517,7 @@ void MyMoneyTransactionFilterTest::testMatchTransactionTag()
     QVERIFY(!filter.match(transaction2));
     QCOMPARE(filter.matchingSplits(transaction2).size(), 0);
 
-    // check enabled category splits support
-    filter.setConsiderCategorySplits(true);
-    QVERIFY(filter.match(transaction2));
-    QCOMPARE(filter.matchingSplits(transaction2).size(), 1);
+    qDebug() << "tags on categories could not be tested";
 }
 
 void MyMoneyTransactionFilterTest::testMatchTransactionTypeAllTypes()
