@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2013-2014 Allan Anderson <agander93@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -23,7 +24,7 @@ class CSVExporter : public KMyMoneyPlugin::Plugin
     Q_OBJECT
 
 public:
-    explicit CSVExporter(QObject *parent, const QVariantList &args);
+    explicit CSVExporter(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~CSVExporter() override;
 
     bool              okToWriteFile(const QUrl &url);
