@@ -66,7 +66,7 @@ public:
 private:
     bool m_firstSplit;
 
-    QMap<QString, QString> m_map;
+    QMultiMap<QString, QString> m_map;
     /**
       * This method writes the entries necessary for an account. First
       * the leadin, and then the transactions that are in the account
@@ -132,8 +132,9 @@ private:
 
     bool m_noError;
 
-    QString format(const QString &s, bool withSeparator = true);
-    QString format(const MyMoneyMoney &value, int prec = 2, bool withSeparator = true);
+    QString format(const QString& s, bool withSeparator = true) const;
+    QString format(const MyMoneyMoney& value, int prec = 2, bool withSeparator = true) const;
+    QString format(const MyMoneyMoney& value, const QString& accountId, bool withSeparator = true) const;
 };
 
 #endif
