@@ -9,7 +9,8 @@
 
 #include "mymoneyfile.h"
 #include "mymoneyaccount.h"
-#include <mymoneystoragemgr.h>
+#include "mymoneysecurity.h"
+#include "mymoneyexception.h"
 
 #include "csvimportercore.h"
 #include "csvimporttestcommon.h"
@@ -23,11 +24,25 @@ void CSVImporterCoreTest::initTestCase()
     MyMoneyMoney::setDecimalSeparator(QLocale().decimalPoint());
 }
 
+void CSVImporterCoreTest::setupBaseCurrency()
+{
+    file = MyMoneyFile::instance();
+
+    MyMoneySecurity base("EUR", "Euro", QChar(0x20ac));
+    MyMoneyFileTransaction ft;
+    try {
+        file->currency(base.id());
+    } catch (const MyMoneyException&) {
+        file->addCurrency(base);
+    }
+    file->setBaseCurrency(base);
+    ft.commit();
+}
+
 void CSVImporterCoreTest::init()
 {
-    storage = new MyMoneyStorageMgr;
+    setupBaseCurrency();
     file = MyMoneyFile::instance();
-    file->attachStorage(storage);
 
     csvImporter = new CSVImporterCore;
 
@@ -88,8 +103,6 @@ void CSVImporterCoreTest::cleanup()
     delete pricesProfile;
     delete amountProfile;
     delete csvImporter;
-    file->detachStorage(storage);
-    delete storage;
 }
 
 void CSVImporterCoreTest::testBasicPriceTable()
