@@ -19,8 +19,8 @@ CurrenciesDlg::CurrenciesDlg() : ui(new Ui::CurrenciesDlg)
     m_buttonOK->setShortcut(Qt::CTRL | Qt::Key_Return);
     m_buttonOK->setEnabled(false);
 
-    connect(ui->cbFrom,  SIGNAL(currentIndexChanged(int)), this,  SLOT(slotIndexChanged(int)));
-    connect(ui->cbTo,  SIGNAL(currentIndexChanged(int)), this,  SLOT(slotIndexChanged(int)));
+    connect(ui->cbFrom, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &CurrenciesDlg::slotIndexChanged);
+    connect(ui->cbTo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &CurrenciesDlg::slotIndexChanged);
 }
 
 CurrenciesDlg::~CurrenciesDlg()
@@ -51,7 +51,7 @@ void CurrenciesDlg::initializeCurrencies(const QString &presetFromCurrency, cons
     ui->cbTo->blockSignals(false);
     ui->cbFrom->setCurrentIndex(presetFromIndex);
     ui->cbTo->setCurrentIndex(presetToIndex);
-    emit ui->cbFrom->currentIndexChanged(presetFromIndex); // in case currentIndex == presetIndex and no signal would be emitted
+    Q_EMIT ui->cbFrom->currentIndexChanged(presetFromIndex); // in case currentIndex == presetIndex and no signal would be emitted
 }
 
 QString CurrenciesDlg::fromCurrency() {
