@@ -44,9 +44,9 @@ PricesPage::PricesPage(CSVWizard *dlg, CSVImporterCore *imp) :
     // initialize column names
     m_dlg->m_colTypeName.insert(Column::Price, i18n("Price"));
     m_dlg->m_colTypeName.insert(Column::Date, i18n("Date"));
-    connect(ui->m_dateCol, SIGNAL(currentIndexChanged(int)), this, SLOT(dateColSelected(int)));
-    connect(ui->m_priceCol, SIGNAL(currentIndexChanged(int)), this, SLOT(priceColSelected(int)));
-    connect(ui->m_priceFraction, SIGNAL(currentIndexChanged(int)), this, SLOT(fractionChanged(int)));
+    connect(ui->m_dateCol, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &PricesPage::dateColSelected);
+    connect(ui->m_priceCol, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &PricesPage::priceColSelected);
+    connect(ui->m_priceFraction, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &PricesPage::fractionChanged);
 }
 
 PricesPage::~PricesPage()
@@ -67,7 +67,7 @@ void PricesPage::initializePage()
         it.value()->setCurrentIndex(m_profile->m_colTypeNum.value(it.key()));
 
     ui->m_priceFraction->blockSignals(true);
-    foreach (const auto priceFraction, m_imp->m_priceFractions)
+    for (const auto& priceFraction : qAsConst(m_imp->m_priceFractions))
         ui->m_priceFraction->addItem(QString::number(priceFraction.toDouble(), 'g', 3));
     ui->m_priceFraction->blockSignals(false);
     ui->m_priceFraction->setCurrentIndex(m_profile->m_priceFraction);
@@ -112,7 +112,7 @@ void PricesPage::priceColSelected(int col)
 void PricesPage::fractionChanged(int col)
 {
     m_profile->m_priceFraction = col;
-    emit completeChanged();
+    Q_EMIT completeChanged();
 }
 
 void PricesPage::clearColumns()
@@ -132,7 +132,7 @@ void PricesPage::resetComboBox(const Column comboBox)
         ui->m_priceCol->setCurrentIndex(-1);
         break;
     default:
-        KMessageBox::sorry(m_dlg, i18n("<center>Field name not recognised.</center><center>'<b>%1</b>'</center>Please re-enter your column selections.", (int)comboBox), i18n("CSV import"));
+        KMessageBox::error(m_dlg, i18n("<center>Field name not recognised.</center><center>'<b>%1</b>'</center>Please re-enter your column selections.", (int)comboBox), i18n("CSV import"));
     }
 }
 
@@ -157,7 +157,7 @@ bool PricesPage::validateSelectedColumn(const int col, const Column type)
         colTypeNum[type] = col; // assign new column 'number' to this 'type'
         colNumType[col] = type; // assign new 'type' to this column 'number'
     }
-    emit completeChanged();
+    Q_EMIT completeChanged();
     return ret;
 }
 
