@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2009 Cristian Onet onet.cristian @gmail.com
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
@@ -12,15 +13,14 @@
 #include "mymoneyaccount.h"
 #include "mymoneykeyvaluecontainer.h"
 
-class QStringList;
-class KPluginInfo;
+#include "qcontainerfwd.h"
 
 class iCalendarExporter: public KMyMoneyPlugin::Plugin
 {
     Q_OBJECT
 
 public:
-    explicit iCalendarExporter(QObject *parent, const QVariantList &args);
+    explicit iCalendarExporter(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~iCalendarExporter() override;
 
 protected Q_SLOTS:
@@ -31,13 +31,13 @@ protected Q_SLOTS:
     void slotExport();
 
     // the plugin loader plugs in a plugin
-    void plug() override;
+    void plug(KXMLGUIFactory* guiFactory) override;
 
     // the plugin loader unplugs a plugin
     void unplug() override;
 
     // the plugin's configurations has changed
-    void configurationChanged() override;
+    void updateConfiguration() override;
 
 private:
     struct Private;
