@@ -11,12 +11,13 @@
 
 // Qt Includes
 #include <QMetaObject>
-#include <QQuickView>
-#include <QQuickItem>
 #include <QPushButton>
-#include <QRegExpValidator>
+#include <QQuickItem>
+#include <QQuickView>
+#include <QRegularExpressionValidator>
 #include <QStandardPaths>
 
+// KDE Includes
 #include <KLocalizedString>
 
 // Project Includes
@@ -33,7 +34,7 @@ chipTanDialog::chipTanDialog(QWidget* parent)
     connect(ui->buttonBox, &QDialogButtonBox::rejected, this, &chipTanDialog::reject);
     connect(ui->tanInput, &QLineEdit::textEdited, this, &chipTanDialog::setTanInput);
 
-    ui->declarativeView->setSource(QUrl(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kbanking/qml/chipTan/ChipTan.qml"))));
+    ui->declarativeView->setSource(QUrl("qrc:/plugins/kbanking/chipTan/ChipTan.qml"));
 
     setFlickerFieldWidth(KBankingSettings::width());
     setFlickerFieldClockSetting(KBankingSettings::clocksetting());
@@ -74,7 +75,7 @@ void chipTanDialog::setInfoText(const QString& text)
 {
     if (text != infoText()) {
         ui->infoText->setText(text);
-        emit infoTextChanged(text);
+        Q_EMIT infoTextChanged(text);
     }
 }
 
@@ -87,7 +88,7 @@ void chipTanDialog::setHhdCode(const QString& code)
 {
     if (hhdCode() != code) {
         setRootObjectProperty("transferData", code);
-        emit hhdCodeChanged(code);
+        Q_EMIT hhdCodeChanged(code);
     }
 }
 
@@ -106,7 +107,7 @@ QString chipTanDialog::tan()
 
 void chipTanDialog::setTanLimits(const int& minLength, const int& maxLength)
 {
-    ui->tanInput->setValidator(new QRegExpValidator(QRegExp(QString("\\d{%1,%2}").arg(minLength).arg(maxLength)), ui->tanInput));
+    ui->tanInput->setValidator(new QRegularExpressionValidator(QRegularExpression(QStringLiteral("\\d{%1,%2}").arg(minLength).arg(maxLength)), ui->tanInput));
 }
 
 int chipTanDialog::flickerFieldWidth()
@@ -140,7 +141,7 @@ void chipTanDialog::setFlickerFieldWidth(const int& width)
         if (width != KBankingSettings::width()) {
             KBankingSettings::setWidth(width);
             KBankingSettings::self()->save();
-            emit flickerFieldWidthChanged(width);
+            Q_EMIT flickerFieldWidthChanged(width);
         }
     }
 }
