@@ -21,11 +21,11 @@ class photoTanDialog;
 class photoTanDialog : public QDialog
 {
     Q_OBJECT
-    Q_PROPERTY(QString infoText READ infoText() WRITE setInfoText CONSTANT)
-    Q_PROPERTY(QPixmap picture READ picture() WRITE setPicture CONSTANT)
+    Q_PROPERTY(QString infoText READ infoText() WRITE setInfoText)
+    Q_PROPERTY(QPixmap picture READ picture() WRITE setPicture)
 
 public:
-    explicit photoTanDialog(QWidget* parent = 0);
+    explicit photoTanDialog(QWidget* parent = nullptr);
     ~photoTanDialog();
 
     enum Result { Accepted = 0, Rejected, InternalError };
