@@ -15,11 +15,16 @@
 #include <QRegularExpression>
 #include <QStandardPaths>
 #include <QTabWidget>
-#include <QTextCodec>
 #include <QTextStream>
 #include <QTimer>
 #include <QUuid>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QTextCodec>
+#else
+#include <QStringDecoder>
+#endif
+
 // ----------------------------------------------------------------------------
 // KDE Includes
 
@@ -65,6 +70,15 @@ KOnlineBankingSetupWizard::KOnlineBankingSetupWizard(QWidget* parent)
     m_appId = new OfxAppVersion(m_applicationCombo, m_applicationEdit, "");
     m_headerVersion = new OfxHeaderVersion(m_headerVersionCombo, "");
 
+    // set password field according to KDE preferences
+    m_editPassword->setEchoMode(QLineEdit::EchoMode::PasswordEchoOnEdit);
+    new PasswordToggle(m_editPassword);
+
+    // make sure to not exceed data fields
+    m_editUsername->setMaxLength(OFX_USERID_LENGTH - 1);
+    m_editPassword->setMaxLength(OFX_USERPASS_LENGTH - 1);
+
+#if 0
     // fill the list view with banks
     QProgressDialog* dlg = new QProgressDialog(this);
     dlg->setWindowTitle(i18n("Loading banklist"));
@@ -76,22 +90,15 @@ KOnlineBankingSetupWizard::KOnlineBankingSetupWizard(QWidget* parent)
     dlg->setMinimumDuration(0);
     QCoreApplication::processEvents();
 
-    //set password field according to KDE preferences
-    m_editPassword->setEchoMode(QLineEdit::EchoMode::PasswordEchoOnEdit);
-    new PasswordToggle(m_editPassword);
-
-    // make sure to not exceed data fields
-    m_editUsername->setMaxLength(OFX_USERID_LENGTH-1);
-    m_editPassword->setMaxLength(OFX_USERPASS_LENGTH-1);
-
     KListWidgetSearchLine* searchLine = new KListWidgetSearchLine(autoTab, m_listFi);
     vboxLayout1->insertWidget(0, searchLine);
     QTimer::singleShot(20, searchLine, SLOT(setFocus()));
 
     OfxPartner::setDirectory(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + "");
     m_listFi->addItems(OfxPartner::BankNames());
-    m_fInit = true;
     delete dlg;
+#endif
+    m_fInit = true;
 
     checkNextButton();
     connect(this, &KOnlineBankingSetupWizard::currentIdChanged, this, &KOnlineBankingSetupWizard::checkNextButton);
@@ -118,6 +125,12 @@ KOnlineBankingSetupWizard::KOnlineBankingSetupWizard(QWidget* parent)
     button(QWizard::NextButton)->setIcon(KStandardGuiItem::forward(KStandardGuiItem::UseRTL).icon());
     button(QWizard::BackButton)->setIcon(KStandardGuiItem::back(KStandardGuiItem::UseRTL).icon());
 
+    // don't show ofxhome.com stuff anymore (but keep it around)
+    m_selectionTab->setCurrentIndex(1);
+    m_selectionTab->tabBar()->hide();
+    m_instructionLabel->setText(
+        i18nc("@title:group Manual enter OFX details", "Please provide the details for your financial institution in the fields below."));
+
     m_problemMessages->setHidden(true);
     m_problemMessages->setWordWrap(true);
 }
@@ -142,8 +155,7 @@ void KOnlineBankingSetupWizard::checkNextButton()
         if (m_selectionTab->currentIndex() == 0) {
             enableButton = (m_listFi->currentItem() != nullptr) && m_listFi->currentItem()->isSelected();
         } else {
-            enableButton = !(m_url->url().isEmpty()
-                             || m_bankName->text().isEmpty());
+            enableButton = !(m_url->url().isEmpty() || m_fid->text().isEmpty() || m_bankName->text().isEmpty());
         }
         break;
 
@@ -349,8 +361,13 @@ bool KOnlineBankingSetupWizard::finishLoginPage()
         QString hver = m_headerVersion->headerVersion();
         strncpy(fi.header_version, hver.toLatin1(), OFX_HEADERVERSION_LENGTH - 1);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         auto codec = QTextCodec::codecForName("Windows-1251");
         auto request = codec->toUnicode(libofx_request_accountinfo(&fi));
+#else
+        auto toUtf16 = QStringDecoder(QLatin1String("Windows-1251"));
+        QString request = toUtf16(libofx_request_accountinfo(&fi));
+#endif
 
         // Check if we need to tweak the request for specific institutions
         MyMoneyOfxConnector::institutionSpecificRequestAdjustment(request);
@@ -368,7 +385,14 @@ bool KOnlineBankingSetupWizard::finishLoginPage()
             metaData.insert(QLatin1String("UserAgent"), userAgent);
         }
 
-        OfxHttpRequest(QString("POST"), QUrl((*m_it_info).url), codec->fromUnicode(request), metaData, filename, false);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        const auto encodedRequest = codec->fromUnicode(request);
+#else
+        auto fromUtf16 = QStringEncoder(QLatin1String("Windows-1251"));
+        const auto encodedRequest = fromUtf16(request);
+#endif
+
+        OfxHttpRequest(QString("POST"), QUrl((*m_it_info).url), encodedRequest, metaData, filename, false);
         backButton->setEnabled(backButtonState);
 
         LibofxContextPtr ctx = libofx_get_new_context();
