@@ -1,5 +1,7 @@
 /*
+
     SPDX-FileCopyrightText: 2013 Christian Dávid <christian-david@web.de>
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -43,7 +45,9 @@ public:
         return m_testNumber;
     }
 
-    void writeXML(QDomDocument&, QDomElement&) const final override {}
+    void writeXML(QXmlStreamWriter*) const final override
+    {
+    }
 
 protected:
 
@@ -54,8 +58,12 @@ protected:
         Q_UNUSED(id);
         return false;
     }
-
-    dummyTask* createFromXml(const QDomElement&) const final override {
+    KMMStringSet referencedObjects() const final override
+    {
+        return {};
+    }
+    dummyTask* createFromXml(QXmlStreamReader*) const final override
+    {
         return (new dummyTask);
     }
 
@@ -63,6 +71,11 @@ protected:
         return QString();
     }
 
+    QString purpose() const final override
+    {
+        return QString();
+    }
+
     int m_testNumber;
 };
 
