@@ -8,18 +8,19 @@
 
 #include <memory>
 
+#include <QElapsedTimer>
 #include <QObject>
 #include <QTemporaryFile>
-#include <QElapsedTimer>
 #include <QUrl>
 
 #define KMM_MYMONEY_UNIT_TESTABLE friend class MyMoneyStorageMgrTest;
 
+#include "../mymoneystoragesql.h"
 #include "mymoneyobject.h"
 #include "mymoneystoragemgr.h"
-#include "../mymoneystoragesql.h"
+#include "mymoneytestutils.h"
 
-class MyMoneyStorageMgrTest : public QObject
+class MyMoneyStorageMgrTest : public QObject, public MyMoneyTestBase
 {
     Q_OBJECT
 
