@@ -76,6 +76,90 @@ static QString _q_escapeIdentifier(const QString &identifier)
     return res;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+using KMMMetaType = QMetaType;
+
+static QMetaType qGetColumnType(int stp)
+{
+    QMetaType::Type fieldType;
+
+    // Get the proper type for the field based on stp value
+    switch (stp) {
+    case SQLITE_INTEGER:
+        fieldType = QMetaType::Int;
+        break;
+    case SQLITE_FLOAT:
+        fieldType = QMetaType::Double;
+        break;
+    case SQLITE_BLOB:
+        fieldType = QMetaType::QByteArray;
+        break;
+    case SQLITE_TEXT:
+        fieldType = QMetaType::QString;
+        break;
+    case SQLITE_NULL:
+    default:
+        fieldType = QMetaType::UnknownType;
+        break;
+    }
+
+    return QMetaType(fieldType);
+}
+
+static QMetaType qGetColumnType(const QString& tpName)
+{
+    const QString typeName = tpName.toLower();
+    QMetaType::Type fieldType;
+
+    if (typeName == QLatin1String("integer") || typeName == QLatin1String("int"))
+        fieldType = QMetaType::Int;
+    else if (typeName == QLatin1String("double") || typeName == QLatin1String("float") || typeName == QLatin1String("real")
+             || typeName.startsWith(QLatin1String("numeric")))
+        fieldType = QMetaType::Double;
+    else if (typeName == QLatin1String("blob"))
+        fieldType = QMetaType::QByteArray;
+    else if (typeName == QLatin1String("boolean") || typeName == QLatin1String("bool"))
+        fieldType = QMetaType::Bool;
+    else
+        fieldType = QMetaType::QString;
+
+    return QMetaType(fieldType);
+}
+
+QMetaType::Type qVariantTypeToMetaType(const QVariant& v)
+{
+    return static_cast<QMetaType::Type>(v.metaType().id());
+}
+#else
+using KMMMetaType = QVariant::Type;
+
+static QVariant::Type qGetColumnType(int stp)
+{
+    QVariant::Type fieldType;
+
+    // Get the proper type for the field based on stp value
+    switch (stp) {
+    case SQLITE_INTEGER:
+        fieldType = QVariant::Int;
+        break;
+    case SQLITE_FLOAT:
+        fieldType = QVariant::Double;
+        break;
+    case SQLITE_BLOB:
+        fieldType = QVariant::ByteArray;
+        break;
+    case SQLITE_TEXT:
+        fieldType = QVariant::String;
+        break;
+    case SQLITE_NULL:
+    default:
+        fieldType = QVariant::Invalid;
+        break;
+    }
+
+    return fieldType;
+}
+
 static QVariant::Type qGetColumnType(const QString &tpName)
 {
     const QString typeName = tpName.toLower();
@@ -96,6 +180,12 @@ static QVariant::Type qGetColumnType(const QString &tpName)
     return QVariant::String;
 }
 
+QMetaType::Type qVariantTypeToMetaType(const QVariant& v)
+{
+    return static_cast<QMetaType::Type>(v.userType());
+}
+#endif
+
 static QSqlError qMakeError(sqlite3 *access, const QString &descr, QSqlError::ErrorType type,
                             int errorCode = -1)
 {
@@ -135,7 +225,10 @@ class QSQLiteDriverPrivate : public QSqlDriverPrivate
     Q_DECLARE_PUBLIC(QSQLiteDriver)
 
 public:
-    inline QSQLiteDriverPrivate() : QSqlDriverPrivate(), access(0) {
+    inline QSQLiteDriverPrivate()
+        : QSqlDriverPrivate()
+        , access(nullptr)
+    {
         dbmsType = QSqlDriver::SQLite;
     }
     sqlite3 *access;
@@ -165,11 +258,11 @@ public:
     QVector<QVariant> firstRow;
 };
 
-QSQLiteResultPrivate::QSQLiteResultPrivate(QSQLiteResult *q, const QSQLiteDriver *drv)
-    : QSqlCachedResultPrivate(q, drv),
-      stmt(0),
-      skippedStatus(false),
-      skipRow(false)
+QSQLiteResultPrivate::QSQLiteResultPrivate(QSQLiteResult* q, const QSQLiteDriver* drv)
+    : QSqlCachedResultPrivate(q, drv)
+    , stmt(nullptr)
+    , skippedStatus(false)
+    , skipRow(false)
 {
 }
 
@@ -191,7 +284,7 @@ void QSQLiteResultPrivate::finalize()
         return;
 
     sqlite3_finalize(stmt);
-    stmt = 0;
+    stmt = nullptr;
 }
 
 void QSQLiteResultPrivate::initColumns(bool emptyResultset)
@@ -218,30 +311,13 @@ void QSQLiteResultPrivate::initColumns(bool emptyResultset)
         // sqlite3_column_type is documented to have undefined behavior if the result set is empty
         int stp = emptyResultset ? -1 : sqlite3_column_type(stmt, i);
 
-        QVariant::Type fieldType;
+        KMMMetaType fieldType;
 
         if (!typeName.isEmpty()) {
             fieldType = qGetColumnType(typeName);
         } else {
             // Get the proper type for the field based on stp value
-            switch (stp) {
-            case SQLITE_INTEGER:
-                fieldType = QVariant::Int;
-                break;
-            case SQLITE_FLOAT:
-                fieldType = QVariant::Double;
-                break;
-            case SQLITE_BLOB:
-                fieldType = QVariant::ByteArray;
-                break;
-            case SQLITE_TEXT:
-                fieldType = QVariant::String;
-                break;
-            case SQLITE_NULL:
-            default:
-                fieldType = QVariant::Invalid;
-                break;
-            }
+            fieldType = qGetColumnType(stp);
         }
 #ifdef ENABLE_COLUMN_METADATA
         QSqlField fld(colName, fieldType, tableName);
@@ -392,7 +468,7 @@ bool QSQLiteResult::prepare(const QString &query)
 
     setSelect(false);
 
-    const void *pzTail = NULL;
+    const void* pzTail = nullptr;
 
 #if (SQLITE_VERSION_NUMBER >= 3003011)
     int res = sqlite3_prepare16_v2(d->drv_d_func()->access, query.constData(), (query.size() + 1) * sizeof(QChar),
@@ -531,39 +607,40 @@ bool QSQLiteResult::exec()
             if (value.isNull()) {
                 res = sqlite3_bind_null(d->stmt, i + 1);
             } else {
-                switch (value.type()) {
-                case QVariant::ByteArray: {
+                QMetaType::Type type = qVariantTypeToMetaType(value);
+                switch (type) {
+                case QMetaType::QByteArray: {
                     const QByteArray *ba = static_cast<const QByteArray*>(value.constData());
                     res = sqlite3_bind_blob(d->stmt, i + 1, ba->constData(),
                                             ba->size(), SQLITE_STATIC);
                     break;
                 }
-                case QVariant::Int:
-                case QVariant::Bool:
+                case QMetaType::Int:
+                case QMetaType::Bool:
                     res = sqlite3_bind_int(d->stmt, i + 1, value.toInt());
                     break;
-                case QVariant::Double:
+                case QMetaType::Double:
                     res = sqlite3_bind_double(d->stmt, i + 1, value.toDouble());
                     break;
-                case QVariant::UInt:
-                case QVariant::LongLong:
+                case QMetaType::UInt:
+                case QMetaType::LongLong:
                     res = sqlite3_bind_int64(d->stmt, i + 1, value.toLongLong());
                     break;
-                case QVariant::DateTime: {
+                case QMetaType::QDateTime: {
                     const QDateTime dateTime = value.toDateTime();
                     const QString str = dateTime.toString(QLatin1String("yyyy-MM-ddThh:mm:ss.zzz") + timespecToString(dateTime));
                     res = sqlite3_bind_text16(d->stmt, i + 1, str.utf16(),
                                               str.size() * sizeof(ushort), SQLITE_TRANSIENT);
                     break;
                 }
-                case QVariant::Time: {
+                case QMetaType::QTime: {
                     const QTime time = value.toTime();
                     const QString str = time.toString(QStringView(u"hh:mm:ss.zzz"));
                     res = sqlite3_bind_text16(d->stmt, i + 1, str.utf16(),
                                               str.size() * sizeof(ushort), SQLITE_TRANSIENT);
                     break;
                 }
-                case QVariant::String: {
+                case QMetaType::QString: {
                     // lifetime of string == lifetime of its qvariant
                     const QString *str = static_cast<const QString*>(value.constData());
                     res = sqlite3_bind_text16(d->stmt, i + 1, str->utf16(),
@@ -801,22 +878,21 @@ bool QSQLiteDriver::open(const QString & db, const QString &, const QString &, c
 
     openMode |= SQLITE_OPEN_NOMUTEX;
 
-    if (sqlite3_open_v2(db.toUtf8().constData(), &d->access, openMode, NULL) == SQLITE_OK) {
+    if (sqlite3_open_v2(db.toUtf8().constData(), &d->access, openMode, nullptr) == SQLITE_OK) {
         sqlite3_busy_timeout(d->access, timeOut);
         setOpen(true);
         setOpenError(false);
 #if QT_CONFIG(regularexpression)
         if (defineRegexp) {
             auto cache = new QCache<QString, QRegularExpression>(regexpCacheSize);
-            sqlite3_create_function_v2(d->access, "regexp", 2, SQLITE_UTF8, cache, &_q_regexp, NULL,
-                                       NULL, &_q_regexp_cleanup);
+            sqlite3_create_function_v2(d->access, "regexp", 2, SQLITE_UTF8, cache, &_q_regexp, nullptr, nullptr, &_q_regexp_cleanup);
         }
 #endif
         return true;
     } else {
         if (d->access) {
             sqlite3_close(d->access);
-            d->access = 0;
+            d->access = nullptr;
         }
 
         setLastError(qMakeError(d->access, tr("Error opening database"),
@@ -835,12 +911,12 @@ void QSQLiteDriver::close()
 
         if (d->access && (d->notificationid.count() > 0)) {
             d->notificationid.clear();
-            sqlite3_update_hook(d->access, NULL, NULL);
+            sqlite3_update_hook(d->access, nullptr, nullptr);
         }
 
         if (sqlite3_close(d->access) != SQLITE_OK)
             setLastError(qMakeError(d->access, tr("Error closing database"), QSqlError::ConnectionError));
-        d->access = 0;
+        d->access = nullptr;
         setOpen(false);
         setOpenError(false);
     }
@@ -1050,7 +1126,7 @@ bool QSQLiteDriver::unsubscribeFromNotification(const QString &name)
 
     d->notificationid.removeAll(name);
     if (d->notificationid.isEmpty())
-        sqlite3_update_hook(d->access, NULL, NULL);
+        sqlite3_update_hook(d->access, nullptr, nullptr);
 
     return true;
 }
