@@ -6,13 +6,12 @@
 
 #include "qsqlcipher-test.h"
 
-#include <QCoreApplication>
-#include <QDebug>
-#include <QSqlError>
-#include <QSqlQuery>
-#include <QSqlRecord>
-#include <QSqlResult>
 #include <QTest>
+#include <QSqlQuery>
+#include <QSqlError>
+#include <QSqlResult>
+#include <QSqlRecord>
+#include <QCoreApplication>
 
 QTEST_GUILESS_MAIN(qsqlciphertest)
 
@@ -65,7 +64,7 @@ void qsqlciphertest::createEncryptedDatabase()
     m_file.open();
     // https://www.sqlite.org/fileformat.html#database_header
     auto header = QString(m_file.read(16));
-    QVERIFY(header !=  QLatin1String("SQLite format 3\000")); // encrypted database has scrambled content in contrast to its regular SQLite counterpart
+    QVERIFY(header != QStringLiteral("SQLite format 3\000")); // encrypted database has scrambled content in contrast to its regular SQLite counterpart
     m_file.close();
 }
 
