@@ -1,6 +1,7 @@
 /*
 
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -9,6 +10,8 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
+#include <QDebug>
+
 // ----------------------------------------------------------------------------
 // KDE Includes
 
@@ -21,12 +24,12 @@
 #include "viewinterface.h"
 #include "kbudgetview.h"
 
-BudgetView::BudgetView(QObject *parent, const QVariantList &args) :
-    KMyMoneyPlugin::Plugin(parent, "budgetview"/*must be the same as X-KDE-PluginInfo-Name*/),
+BudgetView::BudgetView(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args) :
+    KMyMoneyPlugin::Plugin(parent, metaData, args),
     m_view(nullptr)
 {
-    Q_UNUSED(args)
-    setComponentName("budgetview", i18n("Budgets view"));
+    Q_INIT_RESOURCE(budgetview);
+
     // For information, announce that we have been loaded.
     qDebug("Plugins: budgetview loaded");
 }
@@ -36,17 +39,26 @@ BudgetView::~BudgetView()
     qDebug("Plugins: budgetview unloaded");
 }
 
-void BudgetView::plug()
+void BudgetView::plug(KXMLGUIFactory* guiFactory)
 {
     m_view = new KBudgetView;
-    viewInterface()->addView(m_view, i18n("Budgets"), View::Budget, Icons::Icon::Budget);
+
+    // Tell the host application to load my GUI component
+    const auto rcFileName = QLatin1String("budgetview.rc");
+    setXMLFile(rcFileName);
+
+    // create my actions and menus
+    m_view->createActions(guiFactory, this);
+
+    viewInterface()->addView(m_view, i18n("Budgets"), View::Budget, Icons::Icon::Budgets);
 }
 
 void BudgetView::unplug()
 {
+    m_view->removeActions();
     viewInterface()->removeView(View::Budget);
 }
 
-K_PLUGIN_FACTORY_WITH_JSON(BudgetViewFactory, "budgetview.json", registerPlugin<BudgetView>();)
+K_PLUGIN_CLASS_WITH_JSON(BudgetView, "budgetview.json")
 
 #include "budgetview.moc"
