@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -23,11 +24,11 @@ class BudgetView : public KMyMoneyPlugin::Plugin
     Q_OBJECT
 
 public:
-    explicit BudgetView(QObject *parent, const QVariantList &args);
+    explicit BudgetView(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~BudgetView() override;
 
-    void plug() override;
-    void unplug() override;
+    void plug(KXMLGUIFactory* guiFactory) final override;
+    void unplug() final override;
 
 private:
     KBudgetView* m_view;
