@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz lukasz.wojnilowicz @gmail.com
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
@@ -7,9 +8,9 @@
 #include <config-kmymoney-version.h>
 
 // KDE includes
-#include <KPluginFactory>
-#include <KAboutData>
 #include "kmymoneysettings.h"
+#include <KAboutData>
+#include <KPluginFactory>
 
 ForecastViewSettingsWidget::ForecastViewSettingsWidget(QWidget* parent) :
     QWidget(parent)
@@ -17,14 +18,14 @@ ForecastViewSettingsWidget::ForecastViewSettingsWidget(QWidget* parent) :
     setupUi(this);
 }
 
-KCMForecastView::KCMForecastView(QWidget *parent, const QVariantList& args)
-    : KCModule(parent, args)
+KCMForecastView::KCMForecastView(QObject* parent, const QVariantList& args)
+    : KMMKCModule(parent, args)
 {
-    ForecastViewSettingsWidget* w = new ForecastViewSettingsWidget(this);
+    ForecastViewSettingsWidget* w = new ForecastViewSettingsWidget(widget());
     // addConfig(ForecastViewSettings::self(), w);
     addConfig(KMyMoneySettings::self(), w);
     QVBoxLayout *layout = new QVBoxLayout;
-    setLayout(layout);
+    widget()->setLayout(layout);
     layout->addWidget(w);
     setButtons(NoAdditionalButton);
     load();
@@ -34,6 +35,6 @@ KCMForecastView::~KCMForecastView()
 {
 }
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMForecastViewFactory, "kcm_forecastview.json", registerPlugin<KCMForecastView>();)
+K_PLUGIN_CLASS(KCMForecastView)
 
 #include "kcm_forecastview.moc"
