@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2007 Alvaro Soliverez <asoliverez@gmail.com>
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2020 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -13,6 +14,8 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
+class KXMLGUIClient;
+
 // ----------------------------------------------------------------------------
 // Project Includes
 
@@ -43,9 +46,14 @@ public:
     explicit KForecastView(QWidget *parent = nullptr);
     ~KForecastView() override;
 
-    void executeCustomAction(eView::Action action) override;
     void refresh();
 
+    void createActions(KXMLGUIClient* guiClient);
+    void removeActions();
+
+public Q_SLOTS:
+    virtual void slotSettingsChanged() override;
+
 protected:
     void showEvent(QShowEvent* event) override;
 
