@@ -467,6 +467,9 @@ void KOnlineJobOutboxView::showEvent(QShowEvent* event)
         const auto header = d->ui->m_onlineJobView->header();
         d->setSortRole(header->sortIndicatorSection());
         d->ui->m_onlineJobView->sortByColumn(header->sortIndicatorSection(), header->sortIndicatorOrder());
+
+        // Initialize the actions
+        updateActions(d->m_selections);
     }
     // don't forget base class implementation
     QWidget::showEvent(event);
@@ -538,7 +541,7 @@ void KOnlineJobOutboxView::slotOnlineJobSend(QList<onlineJob> jobs)
         if (it_p != d->m_onlinePlugins->cend()) {
             // plugin found, call it
             KMyMoneyPlugin::OnlinePluginExtended *pluginExt = dynamic_cast< KMyMoneyPlugin::OnlinePluginExtended* >(*it_p);
-            if (pluginExt == 0) {
+            if (pluginExt == nullptr) {
                 qWarning("Job given for plugin which is not an extended plugin");
                 continue;
             }
