@@ -67,8 +67,6 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
 {
     if (numberColumns == 0)
         return;
-    //set the number of columns
-    setNumColumns(numberColumns);
 
     //set skipZero
     m_skipZero = config.isSkippingZero();
@@ -161,6 +159,8 @@ void KReportChartView::drawPivotChart(const PivotGrid &grid, const MyMoneyReport
 
         if (config.isIncludingPrice())
             yAxis->setTitleText(i18n("Price"));
+        else if (config.isInvestmentsOnly())
+            yAxis->setTitleText(i18n("Value"));
         else
             yAxis->setTitleText(i18n("Balance"));
 
@@ -780,13 +780,16 @@ void KReportChartView::drawLimitLine(const double limit)
     // This speeds up the runtime of drawLimitLine() by a factor of
     // approx. 60 on my box (1831ms vs. 31ms).
     AbstractDiagram* planeDiagram = coordinatePlane()->diagram();
-    planeDiagram->setModel(0);
+    planeDiagram->setModel(nullptr);
 
-    //we get the current number of rows and we add one after that
-    int row = m_model.rowCount();
-    justifyModelSize(m_numColumns, row + 1);
-    for (int col = 0; col < m_numColumns; ++col) {
-        setDataCell(col, row, limit);
+    // we get the current number of graphs and we add one after that
+    // the rows contains the number x-axis values and the columns
+    // the data for the graph
+    int rows = m_model.rowCount();
+    int cols = m_model.columnCount();
+    justifyModelSize(rows, cols + 1);
+    for (int row = 0; row < rows; ++row) {
+        setDataCell(row, cols, limit);
     }
 
     planeDiagram->setModel(&m_model);
