@@ -93,6 +93,7 @@ public:
         ctPeriodicPayment,
         ctFinalPayment,
         ctPayment,
+        ctReturn,
         /*Shares*/
         ctShares,
         /*Percent*/
@@ -201,6 +202,12 @@ protected:
      * Comma-separated list of columns to place BEFORE the subtotal column
      */
     QList<cellTypeE> m_columns;
+
+    /**
+     * Temporary storage for the price column
+     */
+    QList<cellTypeE> m_priceColumn;
+
     /**
      * Name of the subtotal column
      */
