@@ -13,7 +13,7 @@ class ChartTest: public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void createChart();
 
 };
