@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -24,10 +25,10 @@ class ReportsView : public KMyMoneyPlugin::Plugin, public KMyMoneyPlugin::DataPl
     Q_INTERFACES(KMyMoneyPlugin::DataPlugin)
 
 public:
-    explicit ReportsView(QObject *parent, const QVariantList &args);
-    ~ReportsView() final;
+    explicit ReportsView(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    ~ReportsView();
 
-    void plug() final override;
+    void plug(KXMLGUIFactory* guiFactory) final override;
     void unplug() final override;
 
     QVariant requestData(const QString &arg, uint type) final override;
