@@ -11,7 +11,10 @@
 #include <QWidget>
 #include <QDoubleValidator>
 
+#include "mymoneyenums.h"
+
 class DateRangeDlg;
+class MyMoneyReport;
 
 namespace Ui
 {
@@ -71,6 +74,10 @@ public:
 
     Ui::ReportTabChart* ui;
     void setNegExpenses(bool set);
+    void setPlotExpensesDownwardVisible(bool state);
+    void removeChartType(eMyMoney::Report::ChartType type);
+    bool apply(MyMoneyReport* report);
+    bool load(MyMoneyReport* report);
 
 private Q_SLOTS:
     void slotChartTypeChanged(int index);
@@ -135,7 +142,7 @@ public:
 class MyDoubleValidator : public QDoubleValidator
 {
 public:
-    explicit MyDoubleValidator(int decimals, QObject * parent = 0);
+    explicit MyDoubleValidator(int decimals, QObject* parent = nullptr);
 
     QValidator::State validate(QString &s, int &i) const final override;
 };
