@@ -26,8 +26,12 @@ enum class ExceptionCode {
 class WoobException : public QException
 {
 public:
-    explicit WoobException(ExceptionCode ec) : m_exceptionCode(ec) {}
-    ExceptionCode msg() const {
+    explicit WoobException(ExceptionCode ec)
+        : m_exceptionCode(ec)
+    {
+    }
+    ExceptionCode msg() const
+    {
         return m_exceptionCode;
     }
     void raise() const override
