@@ -15,20 +15,19 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <KCModule>
-
 // ----------------------------------------------------------------------------
 // Project Includes
 
+#include "kmm_kcmodule.h"
 #include "ui_xmlstoragesettings.h"
 
-class PluginSettingsWidget : public QWidget, public Ui::XMLStorageSettings
+class XMLStorageSettingsWidget : public QWidget, public Ui::XMLStorageSettings
 {
     Q_OBJECT
-    Q_DISABLE_COPY(PluginSettingsWidget)
+    Q_DISABLE_COPY(XMLStorageSettingsWidget)
 
 public:
-    explicit PluginSettingsWidget(QWidget* parent = nullptr);
+    explicit XMLStorageSettingsWidget(QWidget* parent = nullptr);
 
 public Q_SLOTS:
     void showEvent(QShowEvent *event) override;
@@ -43,12 +42,13 @@ private:
     int               m_checkCount;
     bool              m_needCheckList;
     bool              m_listOk;
+    QStringList m_recoverKeyList;
 };
 
-class KCMXMLStorage : public KCModule
+class KCMXMLStorage : public KMMKCModule
 {
 public:
-    explicit KCMXMLStorage(QWidget *parent, const QVariantList &args);
+    explicit KCMXMLStorage(QObject* parent, const QVariantList& args = QVariantList());
     ~KCMXMLStorage();
 };
 
