@@ -12,6 +12,7 @@
 
 QString tagName(Tag tagID)
 {
+    // clang-format off
     static const QHash<Tag, QString> tagNames {
         {Tag::Institutions, QStringLiteral("INSTITUTIONS")},
         {Tag::Payees,       QStringLiteral("PAYEES")},
@@ -29,11 +30,14 @@ QString tagName(Tag tagID)
         {Tag::KMMFile,      QStringLiteral("KMYMONEY-FILE")},
         {Tag::FileInfo,     QStringLiteral("FILEINFO")},
         {Tag::User,         QStringLiteral("USER")},
+        {Tag::KeyValuePairs,QStringLiteral("KEYVALUEPAIRS")},
     };
+    // clang-format on
     return tagNames.value(tagID);
 }
 
-uint qHash(const Tag key, uint seed) {
+qHashSeedType qHash(const Tag key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
 
@@ -61,75 +65,99 @@ QString nodeName(Node nodeID)
     return nodeNames.value(nodeID);
 }
 
-uint qHash(const Node key, uint seed) {
+qHashSeedType qHash(const Node key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
 
 namespace Element {
-uint qHash(const General key, uint seed) {
+qHashSeedType qHash(const General key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-uint qHash(const Transaction key, uint seed) {
+qHashSeedType qHash(const Transaction key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-uint qHash(const Account key, uint seed) {
+qHashSeedType qHash(const Account key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-uint qHash(const Payee key, uint seed) {
+qHashSeedType qHash(const Payee key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-uint qHash(const KVP key, uint seed) {
+qHashSeedType qHash(const KVP key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-uint qHash(const Institution key, uint seed) {
+qHashSeedType qHash(const Institution key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-uint qHash(const Schedule key, uint seed) {
+qHashSeedType qHash(const Schedule key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
-uint qHash(const OnlineJob key, uint seed) {
+qHashSeedType qHash(const OnlineJob key, qHashSeedType seed)
+{
     return ::qHash(static_cast<uint>(key), seed);
 }
 }
 
 namespace Attribute {
-uint qHash(const General key, uint seed) {
+qHashSeedType qHash(const General key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const Transaction key, uint seed) {
+qHashSeedType qHash(const Transaction key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const Account key, uint seed) {
+qHashSeedType qHash(const Account key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const Payee key, uint seed) {
+qHashSeedType qHash(const Payee key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const Tag key, uint seed) {
+qHashSeedType qHash(const Tag key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const Security key, uint seed) {
+qHashSeedType qHash(const Security key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const KVP key, uint seed) {
+qHashSeedType qHash(const KVP key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const Institution key, uint seed) {
+qHashSeedType qHash(const Institution key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const Schedule key, uint seed) {
+qHashSeedType qHash(const Schedule key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
-uint qHash(const OnlineJob key, uint seed) {
+qHashSeedType qHash(const OnlineJob key, qHashSeedType seed)
+{
+    Q_UNUSED(seed);
+    return ::qHash(static_cast<uint>(key), 0);
+}
+qHashSeedType qHash(const Reconciliation key, qHashSeedType seed)
+{
     Q_UNUSED(seed);
     return ::qHash(static_cast<uint>(key), 0);
 }
@@ -137,6 +165,7 @@ uint qHash(const OnlineJob key, uint seed) {
 
 QString elementName(Element::General elementID)
 {
+    // clang-format off
     static const QMap<Element::General, QString> elementNames {
         {Element::General::Address,           QStringLiteral("ADDRESS")},
         {Element::General::CreationDate,      QStringLiteral("CREATION_DATE")},
@@ -144,12 +173,15 @@ QString elementName(Element::General elementID)
         {Element::General::Version,           QStringLiteral("VERSION")},
         {Element::General::FixVersion,        QStringLiteral("FIXVERSION")},
         {Element::General::Pair,              QStringLiteral("PAIR")},
+        {Element::General::ApplicationVersion,QStringLiteral("APPVERSION")},
     };
+    // clang-format on
     return elementNames.value(elementID);
 }
 
 QString attributeName(Attribute::General attributeID)
 {
+    // clang-format off
     static const QMap<Attribute::General, QString> attributeNames {
         {Attribute::General::ID,        QStringLiteral("id")},
         {Attribute::General::Date,      QStringLiteral("date")},
@@ -162,12 +194,17 @@ QString attributeName(Attribute::General attributeID)
         {Attribute::General::Price,     QStringLiteral("price")},
         {Attribute::General::Name,      QStringLiteral("name")},
         {Attribute::General::Email,     QStringLiteral("email")},
-        {Attribute::General::Country,   QStringLiteral("county")},
+        {Attribute::General::State,     QStringLiteral("state")},
+        {Attribute::General::Country,   QStringLiteral("country")}, // deprecated, use General::State instead
+        {Attribute::General::AltCountry,QStringLiteral("county")}, // deprecated, was a typo
         {Attribute::General::City,      QStringLiteral("city")},
-        {Attribute::General::ZipCode,   QStringLiteral("zipcode")},
+        {Attribute::General::ZipCode,   QStringLiteral("zip")},
+        {Attribute::General::AltZipCode,QStringLiteral("zipcode")}, // deprecated
+        {Attribute::General::PostCode,  QStringLiteral("postcode")}, // deprecated
         {Attribute::General::Street,    QStringLiteral("street")},
         {Attribute::General::Telephone, QStringLiteral("telephone")},
     };
+    // clang-format on
     return attributeNames.value(attributeID);
 }
 
@@ -230,11 +267,15 @@ QString attributeName(Attribute::Split attributeID)
 
 QString elementName(Element::Account elementID)
 {
+    // clang-format off
     static const QMap<Element::Account, QString> elementNames {
-        {Element::Account::SubAccount,     QStringLiteral("SUBACCOUNT")},
-        {Element::Account::SubAccounts,    QStringLiteral("SUBACCOUNTS")},
-        {Element::Account::OnlineBanking,  QStringLiteral("ONLINEBANKING")},
+        {Element::Account::SubAccount,              QStringLiteral("SUBACCOUNT")},
+        {Element::Account::SubAccounts,             QStringLiteral("SUBACCOUNTS")},
+        {Element::Account::OnlineBanking,           QStringLiteral("ONLINEBANKING")},
+        {Element::Account::ReconciliationHistory,   QStringLiteral("RECONCILIATIONS")},
+        {Element::Account::ReconciliationEntry,     QStringLiteral("RECONCILIATION")},
     };
+    // clang-format on
     return elementNames.value(elementID);
 }
 
@@ -260,6 +301,15 @@ QString attributeName(Attribute::Account attributeID)
     return attributeNames.value(attributeID);
 }
 
+QString attributeName(Attribute::Reconciliation attributeID)
+{
+    static const QHash<Attribute::Reconciliation, QString> attributeNames{
+        {Attribute::Reconciliation::Date, QStringLiteral("date")},
+        {Attribute::Reconciliation::Amount, QStringLiteral("value")},
+    };
+    return attributeNames.value(attributeID);
+}
+
 QString elementName(Element::Payee elementID)
 {
     static const QMap<Element::Payee, QString> elementNames {
@@ -295,6 +345,8 @@ QString attributeName(Attribute::Payee attributeID)
         {Attribute::Payee::AccountNumber,    QStringLiteral("accountnumber")},
         {Attribute::Payee::BankCode,         QStringLiteral("bankcode")},
         {Attribute::Payee::Country,          QStringLiteral("country")},
+        {Attribute::Payee::IdPattern,        QStringLiteral("idpattern")},
+        {Attribute::Payee::UrlTemplate,      QStringLiteral("urltemplate")},
     };
     return attributeNames.value(attributeID);
 }
@@ -360,7 +412,7 @@ QString attributeName(Attribute::Institution attributeID)
         {Attribute::Institution::ID,         QStringLiteral("id")},
         {Attribute::Institution::Name,       QStringLiteral("name")},
         {Attribute::Institution::Manager,    QStringLiteral("manager")},
-        {Attribute::Institution::SortCode,   QStringLiteral("sortcode")},
+        {Attribute::Institution::BankCode,   QStringLiteral("sortcode")},
         {Attribute::Institution::Street,     QStringLiteral("street")},
         {Attribute::Institution::City,       QStringLiteral("city")},
         {Attribute::Institution::Zip,        QStringLiteral("zip")},
