@@ -326,7 +326,19 @@ public:
                 m_fileVersionRead = readUintAttribute(attributeName(Attribute::General::ID), 0, 16);
 
             } else if (tag == elementName(Element::General::FixVersion)) {
-                auto strFixVersion = readUintAttribute(attributeName(Attribute::General::ID));
+                // older versions stored the fixversion in the date attribute and
+                // some intermediate versions had a missing fix version in the id
+                // attribute. The following logic tries to recover from all
+                // scenarios.
+                auto strFixVersion = readUintAttribute(attributeName(Attribute::General::Date));
+                if (strFixVersion == 0) { // not found as date attribute
+                    if (readStringAttribute(attributeName(Attribute::General::ID)).isEmpty()) {
+                        strFixVersion = 5;
+                    } else {
+                        strFixVersion = readUintAttribute(attributeName(Attribute::General::ID));
+                    }
+                }
+
                 // skip KMyMoneyView::fixFile_2()
                 if (strFixVersion == 2)
                     strFixVersion = 3;
@@ -337,6 +349,7 @@ public:
             }
             m_reader->skipCurrentElement();
         }
+        m_file->fileInfoModel()->load(m_fileInformation);
     }
 
     void readUser()
@@ -1220,9 +1233,6 @@ public:
         if (!m_reader->hasError()) {
             auto pairs = m_kvp.pairs();
 
-            // add in the fileinformation so that it is contained
-            // in the parametersModel
-            pairs.insert(m_fileInformation);
             m_file->parametersModel()->load(m_kvp.pairs());
 
             // loading does not count as making dirty
