@@ -28,11 +28,19 @@ enum class SchemeColor {
     Positive,
     Negative,
     TransactionImported,
+    TransactionImportedText,
     TransactionMatched,
+    TransactionMatchedText,
     TransactionErroneous,
     FieldRequired,
     GroupMarker,
+    GroupMarkerText,
     MissingConversionRate,
 };
 
+enum class AutoFillMethod {
+    NoAutoFill = 0,
+    AutoFillWithClosestInValue,
+    AutoFillWithMostOftenUsed,
+};
 #endif
