@@ -1,29 +1,30 @@
 /*
-    SPDX-FileCopyrightText: 2005-2017 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2005-2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2005-2006 Ace Jones <acejones@users.sourceforge.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "testutilities.h"
 
-#include <QList>
-#include <QFile>
-#include <QTextStream>
-#include <QDomDocument>
-#include <QDomElement>
 #include <QDebug>
+#include <QFile>
+#include <QList>
+#include <QRegularExpression>
+#include <QTextStream>
+#include <QXmlStreamReader>
+#include <QXmlStreamWriter>
 
-#include "mymoneyfile.h"
 #include "mymoneyexception.h"
+#include "mymoneyfile.h"
 #include "mymoneymoney.h"
-#include "mymoneysecurity.h"
-#include "mymoneyprice.h"
-#include "mymoneysplit.h"
-#include "mymoneystoragedump.h"
-#include "mymoneyreport.h"
 #include "mymoneypayee.h"
+#include "mymoneyprice.h"
+#include "mymoneyreport.h"
+#include "mymoneysecurity.h"
+#include "mymoneysplit.h"
 #include "mymoneystatement.h"
-#include "plugins/xmlhelper/xmlstoragehelper.h"
+#include "mymoneystoragedump.h"
+#include "xmlhelper/xmlstoragehelper.h"
 
 namespace test
 {
@@ -46,6 +47,7 @@ QString acLiability;
 QString acExpense;
 QString acIncome;
 QString acChecking;
+QString acTransfer;
 QString acCredit;
 QString acSolo;
 QString acParent;
@@ -73,6 +75,7 @@ QString acInterest;
 QString acFees;
 QString acTax;
 QString acCash;
+QString curBase;
 
 TransactionHelper::TransactionHelper(const QDate& _date, const QString& _action, MyMoneyMoney _value, const QString& _accountid, const QString& _categoryid, const QString& _currencyid, const QString& _payee)
 {
@@ -144,13 +147,13 @@ void InvTransactionHelper::init(const QDate& _date, const QString& _action, MyMo
 {
     MyMoneyFile* file = MyMoneyFile::instance();
     MyMoneyAccount stockaccount = file->account(_stockaccountid);
-    MyMoneyMoney value = _shares * _price;
+    MyMoneyMoney priceValue = _shares * _price;
 
     setPostDate(_date);
 
     setCommodity("USD");
     MyMoneySplit s1;
-    s1.setValue(value);
+    s1.setValue(priceValue);
     s1.setAccountId(_stockaccountid);
 
     if (_action == MyMoneySplit::actionName(eMyMoney::Split::Action::ReinvestDividend)) {
@@ -159,13 +162,13 @@ void InvTransactionHelper::init(const QDate& _date, const QString& _action, MyMo
 
         MyMoneySplit s2;
         s2.setAccountId(_categoryid);
-        s2.setShares(-value);
-        s2.setValue(-value);
+        s2.setShares(-priceValue);
+        s2.setValue(-priceValue);
         addSplit(s2);
     } else if (_action == MyMoneySplit::actionName(eMyMoney::Split::Action::Dividend) || _action == MyMoneySplit::actionName(eMyMoney::Split::Action::Yield)) {
         s1.setAccountId(_categoryid);
-        s1.setShares(-value);
-        s1.setValue(-value);
+        s1.setShares(-priceValue);
+        s1.setValue(-priceValue);
 
         // Split 2 will be the zero-amount investment split that serves to
         // mark this transaction as a cash dividend and note which stock account
@@ -179,18 +182,18 @@ void InvTransactionHelper::init(const QDate& _date, const QString& _action, MyMo
 
         MyMoneySplit s3;
         s3.setAccountId(_transferid);
-        s3.setShares(value);
-        s3.setValue(value);
+        s3.setShares(priceValue);
+        s3.setValue(priceValue);
         addSplit(s3);
     } else if (_action == MyMoneySplit::actionName(eMyMoney::Split::Action::BuyShares)) {
         s1.setShares(_shares);
-        s1.setValue(value);
+        s1.setValue(priceValue);
         s1.setAction(MyMoneySplit::actionName(eMyMoney::Split::Action::BuyShares));
 
         MyMoneySplit s3;
         s3.setAccountId(_transferid);
-        s3.setShares(-value - _fee);
-        s3.setValue(-value - _fee);
+        s3.setShares(-priceValue - _fee);
+        s3.setValue(-priceValue - _fee);
         addSplit(s3);
 
         if (!_categoryid.isEmpty() && !_fee.isZero()) {
@@ -228,6 +231,24 @@ void InvTransactionHelper::init(const QDate& _date, const QString& _action, MyMo
     //qDebug() << "successfully added " << id();
 }
 
+QString makeAccount(const QString& id, const QString& _name, eMyMoney::Account::Type _type, MyMoneyMoney _balance, const QDate& _open, const QString& _parent, QString _currency, bool _taxReport, bool _openingBalance)
+{
+    int maxTries = 1000;
+    QString cid;
+    do {
+        if (!cid.isEmpty()) {
+            auto acc = MyMoneyFile::instance()->account(cid);
+            MyMoneyFileTransaction ft;
+            MyMoneyFile::instance()->removeAccount(acc);
+            ft.commit();
+        }
+        cid = makeAccount(_name, _type, _balance, _open, _parent, _currency, _taxReport, _openingBalance);
+    } while(maxTries-- && id != cid);
+    if (maxTries <= 0)
+        throw MYMONEYEXCEPTION_CSTRING("Account could not be prepared");
+    return cid;
+}
+
 QString makeAccount(const QString& _name, eMyMoney::Account::Type _type, MyMoneyMoney _balance, const QDate& _open, const QString& _parent, QString _currency, bool _taxReport, bool _openingBalance)
 {
     MyMoneyAccount info;
@@ -298,18 +319,28 @@ void makeEquityPrice(const QString& _id, const QDate& _date, const MyMoneyMoney&
     ft.commit();
 }
 
-void writeRCFtoXMLDoc(const MyMoneyReport& filter, QDomDocument* doc)
+QString makeBaseCurrency(const MyMoneySecurity& base)
 {
-    QDomProcessingInstruction instruct = doc->createProcessingInstruction(QString("xml"), QString("version=\"1.0\" encoding=\"utf-8\""));
-    doc->appendChild(instruct);
+    auto file = MyMoneyFile::instance();
+    MyMoneyFileTransaction ft;
+    try {
+        file->currency(base.id());
+    } catch (const MyMoneyException&) {
+        file->addCurrency(base);
+    }
+    file->setBaseCurrency(base);
+    ft.commit();
+    return base.id();
+}
 
-    QDomElement root = doc->createElement("KMYMONEY-FILE");
-    doc->appendChild(root);
-
-    QDomElement reports = doc->createElement("REPORTS");
-    root.appendChild(reports);
-
-    MyMoneyXmlContentHandler2::writeReport(filter, *doc, reports);
+void writeRCFtoXMLDoc(const MyMoneyReport& filter, QXmlStreamWriter* writer)
+{
+    writer->writeDTD(QLatin1String("<!DOCTYPE KMYMONEY-FILE>"));
+    writer->writeStartElement(QLatin1String("KMYMONEY-FILE"));
+    writer->writeStartElement(QLatin1String("REPORTS"));
+    MyMoneyXmlHelper::writeReport(filter, writer);
+    writer->writeEndElement();
+    writer->writeEndElement();
 }
 
 void writeRCFtoXML(const MyMoneyReport& filter, const QString& _filename)
@@ -321,43 +352,43 @@ void writeRCFtoXML(const MyMoneyReport& filter, const QString& _filename)
         ++filenum;
     }
 
-    QDomDocument* doc = new QDomDocument("KMYMONEY-FILE");
-    Q_CHECK_PTR(doc);
-
-    writeRCFtoXMLDoc(filter, doc);
-
     QFile g(filename);
     g.open(QIODevice::WriteOnly);
 
-    QTextStream stream(&g);
-    stream.setCodec("UTF-8");
-    stream << doc->toString();
-    g.close();
+    QXmlStreamWriter writer(&g);
+    writeRCFtoXMLDoc(filter, &writer);
 
-    delete doc;
+    g.close();
 }
 
-bool readRCFfromXMLDoc(QList<MyMoneyReport>& list, QDomDocument* doc)
+bool readRCFfromXMLDoc(QList<MyMoneyReport>& list, QXmlStreamReader* reader)
 {
     bool result = false;
 
-    QDomElement rootElement = doc->documentElement();
-    if (!rootElement.isNull()) {
-        QDomNode child = rootElement.firstChild();
-        while (!child.isNull() && child.isElement()) {
-            QDomElement childElement = child.toElement();
-            if ("REPORTS" == childElement.tagName()) {
-                result = true;
-                QDomNode subchild = child.firstChild();
-                while (!subchild.isNull() && subchild.isElement()) {
-                    auto filter = MyMoneyXmlContentHandler2::readReport(subchild.toElement());
-                    list += filter;
-                    subchild = subchild.nextSibling();
+    while (reader->readNextStartElement()) {
+        if (reader->name() == QLatin1String("KMYMONEY-FILE")) {
+            while (reader->readNextStartElement()) {
+                if (reader->name() == QLatin1String("REPORTS")) {
+                    while (reader->readNextStartElement()) {
+                        if (reader->name() == QLatin1String("REPORT")) {
+                            result = true;
+                            const auto filter = MyMoneyXmlHelper::readReport(reader);
+                            if (reader->hasError())
+                                qDebug() << reader->errorString();
+                            list += filter;
+                        } else {
+                            reader->skipCurrentElement();
+                        }
+                    }
+                } else {
+                    reader->skipCurrentElement();
                 }
             }
-            child = child.nextSibling();
+        } else {
+            reader->skipCurrentElement();
         }
     }
+
     return result;
 }
 
@@ -366,11 +397,11 @@ bool readRCFfromXML(QList<MyMoneyReport>& list, const QString& filename)
     int result = false;
     QFile f(filename);
     f.open(QIODevice::ReadOnly);
-    QDomDocument* doc = new QDomDocument;
-    if (doc->setContent(&f, false)) {
-        result = readRCFfromXMLDoc(list, doc);
-    }
-    delete doc;
+
+    QXmlStreamReader reader;
+    reader.setDevice(&f);
+
+    result = readRCFfromXMLDoc(list, &reader);
 
     return result;
 
@@ -383,26 +414,25 @@ void XMLandback(MyMoneyReport& filter)
     // in all cases, the result should be the same if the read
     // & write methods are working correctly.
 
-    QDomDocument* doc = new QDomDocument("KMYMONEY-FILE");
-    Q_CHECK_PTR(doc);
+    QString xml;
+    QXmlStreamWriter writer(&xml);
 
-    writeRCFtoXMLDoc(filter, doc);
+    writeRCFtoXMLDoc(filter, &writer);
+    QXmlStreamReader reader(xml);
     QList<MyMoneyReport> list;
-    if (readRCFfromXMLDoc(list, doc) && !list.isEmpty())
+    if (readRCFfromXMLDoc(list, &reader) && !list.isEmpty())
         filter = list[0];
     else
         throw MYMONEYEXCEPTION_CSTRING("Failed to load report from XML");
-
-    delete doc;
-
 }
 
 MyMoneyMoney searchHTML(const QString& _html, const QString& _search)
 {
     Q_UNUSED(_html)
-    QRegExp re(QString("%1[<>/td]*([\\-.0-9,]*)").arg(_search));
-    if (re.indexIn(_html) > -1) {
-        QString found = re.cap(1);
+    const QRegularExpression re(QStringLiteral("%1[<>/td]*([\\-.0-9,]*)").arg(_search));
+    const auto html(re.match(_html));
+    if (html.hasMatch()) {
+        auto found = html.captured(1);
         found.remove(',');
 
         return MyMoneyMoney(found.toDouble());
