@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2005-2017 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2005-2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2005-2006 Ace Jones <acejones@users.sourceforge.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,11 +10,13 @@
 #include <QList>
 #include <QDate>
 
-class QDomDocument;
+class QXmlStreamWriter;
+class QXmlStreamReader;
 
 #include "mymoneyaccount.h"
 #include "mymoneytransaction.h"
 #include "mymoneymoney.h"
+#include "mymoneysecurity.h"
 class MyMoneyReport;
 
 namespace reports
@@ -44,6 +46,7 @@ extern QString acLiability;
 extern QString acExpense;
 extern QString acIncome;
 extern QString acChecking;
+extern QString acTransfer;
 extern QString acCredit;
 extern QString acSolo;
 extern QString acParent;
@@ -71,6 +74,7 @@ extern QString acInterest;
 extern QString acFees;
 extern QString acTax;
 extern QString acCash;
+extern QString curBase;
 
 class TransactionHelper: public MyMoneyTransaction
 {
@@ -108,13 +112,15 @@ class BudgetHelper: public QList<BudgetEntryHelper>
     MyMoneyMoney budgetAmount(const QDate& _date, const QString& _categoryid, bool& _applytosub);
 };
 
+extern QString makeBaseCurrency(const MyMoneySecurity& currency = MyMoneySecurity("EUR", "Euro", QChar(0x20ac)));
+extern QString makeAccount(const QString& id, const QString& _name, eMyMoney::Account::Type _type, MyMoneyMoney _balance, const QDate& _open, const QString& _parent, QString _currency = "", bool _taxReport = false, bool _openingBalance = false);
 extern QString makeAccount(const QString& _name, eMyMoney::Account::Type _type, MyMoneyMoney _balance, const QDate& _open, const QString& _parent, QString _currency = "", bool _taxReport = false, bool _openingBalance = false);
 extern void makePrice(const QString& _currencyid, const QDate& _date, const MyMoneyMoney& _price);
 QString makeEquity(const QString& _name, const QString& _symbol);
 extern void makeEquityPrice(const QString& _id, const QDate& _date, const MyMoneyMoney& _price);
-extern void writeRCFtoXMLDoc(const MyMoneyReport& filter, QDomDocument* doc);
+extern void writeRCFtoXMLDoc(const MyMoneyReport& filter, QXmlStreamWriter* writer);
 extern void writeRCFtoXML(const MyMoneyReport& filter, const QString& _filename = QString());
-extern bool readRCFfromXMLDoc(QList<MyMoneyReport>& list, QDomDocument* doc);
+extern bool readRCFfromXMLDoc(QList<MyMoneyReport>& list, QXmlStreamReader* reader);
 extern bool readRCFfromXML(QList<MyMoneyReport>& list, const QString& filename);
 extern void XMLandback(MyMoneyReport& filter);
 extern MyMoneyMoney searchHTML(const QString& _html, const QString& _search);
