@@ -1,6 +1,6 @@
 /*
-    SPDX-FileCopyrightText: 2007 Thomas Baumgart <ipwizard@users.sourceforge.net>
-    SPDX-FileCopyrightText: 2017, 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2007-2019 Thomas Baumgart <ipwizard@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2017-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -16,11 +16,12 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "kmymoneyaccountsviewbase.h"
+#include "kmymoneyviewbase.h"
 
 class MyMoneyMoney;
 class MyMoneyAccount;
 class MyMoneyObject;
+class SelectedObjects;
 
 namespace eMenu {
 enum class Action;
@@ -36,7 +37,7 @@ template <class Key, class Value> class QMap;
   */
 
 class KAccountsViewPrivate;
-class KAccountsView : public KMyMoneyAccountsViewBase
+class KAccountsView : public KMyMoneyViewBase
 {
     Q_OBJECT
 
@@ -44,19 +45,15 @@ public:
     explicit KAccountsView(QWidget *parent = nullptr);
     ~KAccountsView();
 
-    void executeCustomAction(eView::Action action) override;
     void refresh();
-    void updateActions(const MyMoneyObject &obj);
 
 public Q_SLOTS:
-    void slotNetWorthChanged(const MyMoneyMoney &);
-    void slotShowAccountMenu(const MyMoneyAccount& acc);
+    void slotNetWorthChanged(const MyMoneyMoney &netWorth, bool isApproximate);
 
-    void slotSelectByObject(const MyMoneyObject& obj, eView::Intent intent) override;
-    void slotSelectByVariant(const QVariantList& variant, eView::Intent intent) override;
+    void slotSettingsChanged() override;
+    void updateActions(const SelectedObjects& selections) override;
 
-protected:
-    void showEvent(QShowEvent * event) override;
+    virtual void setOnlinePlugins(QMap<QString, KMyMoneyPlugin::OnlinePlugin*>* plugins) override;
 
 private:
     Q_DECLARE_PRIVATE(KAccountsView)
@@ -66,15 +63,16 @@ private Q_SLOTS:
     void slotNewAccount();
     void slotEditAccount();
     void slotDeleteAccount();
-    void slotCloseAccount();
-    void slotReopenAccount();
-    void slotChartAccountBalance();
     void slotNewCategory();
     void slotNewPayee(const QString& nameBase, QString& id);
     void slotAccountMapOnline();
     void slotAccountUnmapOnline();
     void slotAccountUpdateOnline();
     void slotAccountUpdateOnlineAll();
+
+Q_SIGNALS:
+    void beginImportingStatements();
+    void endImportingStatements();
 };
 
 #endif
