@@ -6,6 +6,7 @@
     SPDX-FileCopyrightText: 2000-2002 Thomas Baumgart <ipwizard@users.sourceforge.net>
     SPDX-FileCopyrightText: 2000-2002 Kevin Tambascio <ktambascio@users.sourceforge.net>
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KHOMEVIEW_H
@@ -41,11 +42,12 @@ public:
     ~KHomeView() override;
 
     void executeCustomAction(eView::Action action) override;
+    void executeAction(eMenu::Action action, const SelectedObjects& selections) override;
     void refresh();
 
 protected:
+    void resizeEvent(QResizeEvent* event) override;
     void showEvent(QShowEvent* event) override;
-    void wheelEvent(QWheelEvent *event) override;
     bool eventFilter(QObject* o, QEvent* e) override;
 
 public Q_SLOTS:
@@ -53,6 +55,10 @@ public Q_SLOTS:
       * Print the current view
       */
     void slotPrintView();
+    void slotPrintPreviewView();
+    void slotSettingsChanged() override;
+    void slotDisableRefresh();
+    void slotEnableRefresh();
 
 private:
     Q_DECLARE_PRIVATE(KHomeView)
