@@ -89,6 +89,9 @@ public:
         m_needLoad = false;
         ui->setupUi(q);
 
+        // initially disabled
+        ui->m_ledgerButton->setEnabled(false);
+
         // Equities tab
         m_accountsProxyModel = new AccountNamesFilterProxyModel(q);
         m_accountsProxyModel->setObjectName("m_accountsProxyModel");
@@ -469,6 +472,7 @@ void KInvestmentView::showEvent(QShowEvent* event)
         connect(d->ui->m_accountComboBox, &KMyMoneyAccountCombo::accountSelected, this, [&](const QString& accId) {
             Q_D(KInvestmentView);
             d->loadAccount(accId);
+            d->ui->m_ledgerButton->setDisabled(accId.isEmpty());
         });
 
         connect(MyMoneyFile::instance()->accountsModel(), &AccountsModel::rowsInserted, this, [&]() {
@@ -483,6 +487,16 @@ void KInvestmentView::showEvent(QShowEvent* event)
             }
         });
 
+        connect(d->ui->m_ledgerButton, &QToolButton::clicked, this, [&]() {
+            Q_D(KInvestmentView);
+            const auto id = d->m_equitySelections.firstSelection(SelectedObjects::Account);
+            if (!id.isEmpty()) {
+                const auto gotoAccount = pActions[eMenu::Action::GoToAccount];
+                gotoAccount->setData(id);
+                gotoAccount->trigger();
+            }
+        });
+
         d->selectDefaultInvestmentAccount();
     }
 
@@ -636,12 +650,15 @@ void KInvestmentView::slotUpdatePriceManually()
         try {
             auto security = MyMoneyFile::instance()->security(d->currentEquity().currencyId());
             auto currency = MyMoneyFile::instance()->security(security.tradingCurrency());
-            const auto& price = MyMoneyFile::instance()->price(security.id(), currency.id());
+            const auto price = MyMoneyFile::instance()->price(security.id(), currency.id());
 
-            QPointer<KCurrencyCalculator> calc =
-                new KCurrencyCalculator(security, currency, MyMoneyMoney::ONE,
-                                        price.rate(currency.id()), price.date(),
-                                        MyMoneyMoney::precToDenom(security.pricePrecision()));
+            QPointer<KCurrencyCalculator> calc = new KCurrencyCalculator(security,
+                                                                         currency,
+                                                                         MyMoneyMoney::ONE,
+                                                                         price.rate(currency.id()),
+                                                                         price.date(),
+                                                                         MyMoneyMoney::precToDenom(security.pricePrecision()),
+                                                                         this);
             calc->setupPriceEditor();
 
             // The dialog takes care of adding the price if necessary
