@@ -294,6 +294,12 @@ void KMyMoneyView::updateViewType()
                 }
             }
         }
+
+        // KF6 has a search widget which we don't need so we hide it
+        auto pageSearchWidget = findChild<QWidget*>("KPageView::Search");
+        if (pageSearchWidget) {
+            pageSearchWidget->hide();
+        }
     }
 }
 
@@ -343,6 +349,7 @@ void KMyMoneyView::addView(KMyMoneyViewBase* view, const QString& name, View idV
     connect(view, &KMyMoneyViewBase::viewStateChanged, d->viewFrames[idView], &KPageWidgetItem::setEnabled);
     connect(view, SIGNAL(requestSelectionChange(SelectedObjects)), this, SLOT(_q_selectionChangeRequested(SelectedObjects)));
     connect(view, &KMyMoneyViewBase::requestView, this, &KMyMoneyView::switchView);
+    connect(view, &KMyMoneyViewBase::editTransaction, this, &KMyMoneyView::editTransaction);
 
     d->addSharedActions(view);
 }
@@ -362,6 +369,7 @@ void KMyMoneyView::removeView(View idView)
     if (!view)
         return;
 
+    disconnect(view, &KMyMoneyViewBase::editTransaction, this, &KMyMoneyView::editTransaction);
     disconnect(view, &KMyMoneyViewBase::viewStateChanged, d->viewFrames[idView], &KPageWidgetItem::setEnabled);
     disconnect(view, SIGNAL(requestSelectionChange(SelectedObjects)), this, SLOT(_q_selectionChangeRequested(SelectedObjects)));
 
@@ -437,6 +445,7 @@ void KMyMoneyView::updateActions(const SelectedObjects& selections)
         pActions[eMenu::Action::SelectAllTransactions]->setEnabled(true);
         if (selections.selection(SelectedObjects::JournalEntry).isEmpty()) {
             pActions[eMenu::Action::EditTransaction]->setDisabled(true);
+            pActions[eMenu::Action::ToggleReconciliationFlag]->setDisabled(true);
             pActions[eMenu::Action::EditSplits]->setDisabled(true);
             pActions[eMenu::Action::DeleteTransaction]->setDisabled(true);
             pActions[eMenu::Action::DuplicateTransaction]->setDisabled(true);
@@ -447,13 +456,14 @@ void KMyMoneyView::updateActions(const SelectedObjects& selections)
         } else {
             const auto warnLevel = MyMoneyUtils::transactionWarnLevel(selections.selection(SelectedObjects::JournalEntry));
             pActions[eMenu::Action::EditTransaction]->setEnabled(true);
+            pActions[eMenu::Action::ToggleReconciliationFlag]->setEnabled(true);
             pActions[eMenu::Action::EditSplits]->setEnabled(selections.selection(SelectedObjects::JournalEntry).count() == 1);
             pActions[eMenu::Action::DeleteTransaction]->setEnabled(warnLevel <= OneSplitReconciled);
             pActions[eMenu::Action::DuplicateTransaction]->setEnabled(warnLevel <= OneSplitReconciled);
             pActions[eMenu::Action::AddReversingTransaction]->setEnabled(warnLevel <= OneSplitReconciled);
             pActions[eMenu::Action::DisplayTransactionDetails]->setEnabled(true);
             pActions[eMenu::Action::CopySplits]->setDisabled(true);
-            pActions[eMenu::Action::MoveToToday]->setEnabled(true);
+            pActions[eMenu::Action::MoveToToday]->setEnabled(warnLevel <= OneSplitFrozen);
             // TODO: limit to transactions with a related payee
             pActions[eMenu::Action::TransactionOpenURL]->setEnabled(true);
 
