@@ -560,6 +560,9 @@ void KTagsView::showEvent(QShowEvent* event)
             d->m_transactionFilter->setHideReconciledTransactions(LedgerViewSettings::instance()->hideReconciledTransactions());
             d->m_transactionFilter->setHideTransactionsBefore(LedgerViewSettings::instance()->hideTransactionsBefore());
         });
+
+        // forward edit transaction signal
+        connect(d->ui->m_register, &LedgerView::editTransaction, this, &KMyMoneyViewBase::editTransaction);
     }
     // don't forget base class implementation
     QWidget::showEvent(event);
@@ -584,7 +587,7 @@ void KTagsView::updateActions(const SelectedObjects& selections)
         d->clearItemData();
         break;
     case 1:
-        d->ui->m_tabWidget->setEnabled(true); // disable tab widget
+        d->ui->m_tabWidget->setEnabled(true); // enable tab widget
         d->ui->m_balanceLabel->show();
         pActions[eMenu::Action::DeleteTag]->setEnabled(true);
         pActions[eMenu::Action::RenameTag]->setEnabled(true);
@@ -825,3 +828,17 @@ void KTagsView::slotDeleteTag()
         KMessageBox::detailedError(this, i18n("Unable to remove tag(s)"), QString::fromLatin1(e.what()));
     }
 }
+
+void KTagsView::executeAction(eMenu::Action action, const SelectedObjects& selections)
+{
+    Q_UNUSED(selections)
+
+    Q_D(KTagsView);
+    switch (action) {
+    case eMenu::Action::FileClose:
+        d->m_selections.clearSelections();
+        break;
+    default:
+        break;
+    }
+}
