@@ -94,6 +94,7 @@ public:
         , showValuesInverted(false)
         , newTransactionPresent(false)
         , reselectAfterResetPending(false)
+        , resizeToContents(false)
         , selectOnly(false)
     {
         infoMessage->hide();
@@ -529,6 +530,7 @@ public:
     bool showValuesInverted;
     bool newTransactionPresent;
     bool reselectAfterResetPending;
+    bool resizeToContents;
     bool selectOnly;
     QString accountId;
     QString groupName;
@@ -611,6 +613,13 @@ LedgerView::LedgerView(QWidget* parent)
     connect(horizontalHeader(), &QHeaderView::sectionClicked, this, [&]() {
         Q_EMIT modifySortOrder();
     });
+
+    connect(horizontalHeader(), &QHeaderView::sectionHandleDoubleClicked, this, [&](int section) {
+        d->resizeToContents = true;
+        resizeColumnToContents(section);
+        d->resizeToContents = false;
+    });
+
     setTabKeyNavigation(false);
 }
 
@@ -637,7 +646,7 @@ void LedgerView::setModel(QAbstractItemModel* model)
 {
     if (!d->columnSelector) {
         d->columnSelector = new ColumnSelector(this, d->groupName);
-        connect(d->columnSelector, &ColumnSelector::columnsChanged, MyMoneyFile::instance()->journalModel(), &JournalModel::resetRowHeightInformation);
+        connect(d->columnSelector, &ColumnSelector::columnsChanged, this, &LedgerView::slotSettingsChanged);
     }
     QSignalBlocker blocker(this);
     QTableView::setModel(model);
@@ -673,6 +682,7 @@ void LedgerView::reset()
     if (d->editor) {
         closeEditor(d->editor, QAbstractItemDelegate::NoHint);
         d->editor->deleteLater();
+        d->editor = nullptr;
     }
 
     // make sure to kick-off re-selection only once
@@ -790,6 +800,14 @@ bool LedgerView::edit(const QModelIndex& index, QAbstractItemView::EditTrigger t
 
                 d->blockSectionResize();
                 d->columnSelector->setColumnSelectionDisabled();
+
+                // announce that we are editing a transaction
+                Q_EMIT editTransaction(this, true);
+
+                // and announce when we are done too
+                connect(d->editor, &QObject::destroyed, this, [&]() {
+                    Q_EMIT editTransaction(this, false);
+                });
             }
         }
         return rc;
@@ -1703,7 +1721,10 @@ void LedgerView::slotMoveToAccount(const QString& accountId)
     }
 
     pActions[eMenu::Action::MoveTransactionTo]->setData(accountId);
+    const bool enabled = pActions[eMenu::Action::MoveTransactionTo]->isEnabled();
+    pActions[eMenu::Action::MoveTransactionTo]->setEnabled(true);
     pActions[eMenu::Action::MoveTransactionTo]->activate(QAction::Trigger);
+    pActions[eMenu::Action::MoveTransactionTo]->setEnabled(enabled);
 }
 
 void LedgerView::resizeSection(QWidget* view, const QString& configGroupName, int section, int oldSize, int newSize)
@@ -1761,3 +1782,8 @@ void LedgerView::setSelectOnly(bool selectOnly)
 {
     d->selectOnly = selectOnly;
 }
+
+bool LedgerView::isResizingSectionToContents() const
+{
+    return d->resizeToContents;
+}
