@@ -36,6 +36,7 @@
 #include "kmymoneyaccountcombo.h"
 #include "kmymoneysettings.h"
 #include "kmymoneyviewbase_p.h"
+#include "ledgerview.h"
 #include "ledgerviewpage.h"
 #include "menuenums.h"
 #include "mymoneyaccount.h"
@@ -272,6 +273,10 @@ public:
                 // makes sure that all signals about the new selection are emitted
                 ui->ledgerTab->setCurrentIndex(ui->ledgerTab->count()-1);
                 ui->ledgerTab->setCurrentIndex(newIdx);
+                // let the newly opened ledger receive the keyboard focus
+                const auto ledgerView = view->findChild<LedgerView*>();
+                if (ledgerView)
+                    ledgerView->setFocus();
             }
 
             q->connect(view, &LedgerViewPage::requestSelectionChanged, q, &SimpleLedgerView::requestSelectionChange);
@@ -285,6 +290,9 @@ public:
             q->connect(q, &SimpleLedgerView::moveSection, view, &LedgerViewPage::moveSection);
 
             q->connect(view, &LedgerViewPage::requestView, q, &SimpleLedgerView::requestView);
+
+            // forward edit transaction signal
+            q->connect(view, &LedgerViewPage::editTransaction, q, &SimpleLedgerView::editTransaction);
         }
     }
 
@@ -566,9 +574,8 @@ bool SimpleLedgerView::eventFilter(QObject* o, QEvent* e)
                 d->hideAccountsCombo();
                 return true;
             }
-        } else if (o == d->ui->ledgerTab) {
-            // Pressing the + key on the active tab opens the account selector
-            if ((kev->key() == Qt::Key_Plus) && (kev->modifiers() == Qt::NoModifier)) {
+        } else {
+            if (QKeySequence(kev->modifiers() | kev->key()).matches(pActions[eMenu::Action::LedgerQuickOpen]->shortcut())) {
                 d->showAccountSelector(this);
                 return true;
             }
