@@ -80,6 +80,7 @@ public:
         , m_isReadOnly(false)
         , m_allowModifyShares(true)
         , m_isEnabled(qq->isEnabled())
+        , m_lastChangeWasRemove(false)
         , m_actionIcons(NoItem)
         , m_initialExchangeRate(MyMoneyMoney::ONE)
         , m_state(AmountEdit::DisplayValue)
@@ -330,6 +331,12 @@ public:
             widgetTextCache = txt;
             if (q->isEnabled() && !txt.isEmpty()) {
                 ensureFractionalPart(widgetTextCache, state);
+                // ensureFractionalPart is used to add digits but
+                // ist should not remove some. If that's the
+                // case we revert what it has done
+                if (widgetTextCache.length() < txt.length()) {
+                    widgetTextCache = txt;
+                }
             }
             // only update text if it really differs
             if (m_state == state && widgetTextCache.compare(q->QLineEdit::text())) {
@@ -362,6 +369,29 @@ public:
         q->QLineEdit::setReadOnly(ro);
     }
 
+    /**
+     * This updates the widget defined by @a widgetSelector which
+     * could be @c AmountEdit::DisplayValue or @c AmountEdit::DisplayShares.
+     * In case the last change to the widget was the removal of a
+     * character, the precision is unlimited and the value of the
+     * updated string did not change, we keep what is in the widget
+     * and do not modify it.
+     */
+    void updateWidgetText(const AmountEdit::DisplayState widgetSelector, const MyMoneyMoney& amount)
+    {
+        auto& widget = (widgetSelector == AmountEdit::DisplayValue) ? m_valueText : m_sharesText;
+        const auto fract = precision(widgetSelector);
+        auto txt(amount.formatMoney(QString(), fract, false));
+
+        // the following logic checks that we keep a possible decimal
+        // symbol in the display when the last digit after the decimal
+        // symbol has been removed and no specific precision is known
+        if (m_lastChangeWasRemove && (fract == -1) && (MyMoneyMoney(widget) == MyMoneyMoney(txt))) {
+            txt = widget;
+        }
+        setWidgetText(widget, amount, txt, widgetSelector);
+    }
+
     AmountEdit* q_ptr;
     QFrame* m_calculatorFrame;
     KMyMoneyCalculator* m_calculator;
@@ -373,6 +403,7 @@ public:
     bool m_isReadOnly; // read only state as set by application
     bool m_allowModifyShares; // allow to override shares even if read only state
     bool m_isEnabled;
+    bool m_lastChangeWasRemove;
     QString m_previousText; // keep track of what has been typed
 
     QString m_valueText; // keep track of what was the original value
@@ -476,7 +507,7 @@ void AmountEdit::resizeEvent(QResizeEvent* event)
 void AmountEdit::focusInEvent(QFocusEvent* event)
 {
     QLineEdit::focusInEvent(event);
-    if ((event->reason() == Qt::MouseFocusReason) || (event->reason() == Qt::ActiveWindowFocusReason)) {
+    if (event->reason() != Qt::ActiveWindowFocusReason) {
         if (!hasSelectedText()) {
             // we need to wait until all processing is done before
             // we can successfully call selectAll. Hence the
@@ -491,23 +522,25 @@ void AmountEdit::focusOutEvent(QFocusEvent* event)
     Q_D(AmountEdit);
     QLineEdit::focusOutEvent(event);
 
-    // make sure we have a zero value in case the current text
-    // is empty but this is not allowed
-    if (text().isEmpty() && !d->m_allowEmpty) {
-        QLineEdit::setText(QLatin1String("0"));
-    }
+    if (event->reason() != Qt::ActiveWindowFocusReason) {
+        // make sure we have a zero value in case the current text
+        // is empty but this is not allowed
+        if (text().isEmpty() && !d->m_allowEmpty) {
+            QLineEdit::setText(QLatin1String("0"));
+        }
 
-    // make sure we have a fractional part
-    if (!text().isEmpty())
-        ensureFractionalPart();
+        // make sure we have a fractional part
+        if (!text().isEmpty())
+            ensureFractionalPart();
 
-    // in case the widget contains a different value we emit
-    // the amountChanged signal
-    if ((d->m_value != value()) || (d->m_shares != shares())) {
-        d->m_value = value();
-        d->m_shares = shares();
-        d->valueSet = true;
-        Q_EMIT amountChanged();
+        // in case the widget contains a different value we emit
+        // the amountChanged signal
+        if ((d->m_value != value()) || (d->m_shares != shares())) {
+            d->m_value = value();
+            d->m_shares = shares();
+            d->valueSet = true;
+            Q_EMIT amountChanged();
+        }
     }
 }
 
@@ -561,7 +594,7 @@ void AmountEdit::keyPressEvent(QKeyEvent* event)
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 key = QLocale().decimalPoint().unicode();
 #else
-                key = QLocale().decimalPoint().unicode()->toLatin1(); // TODO Test this
+                key = QLocale().decimalPoint().at(0).unicode();
 #endif
                 keyText = QLocale().decimalPoint();
             }
@@ -649,8 +682,7 @@ void AmountEdit::setValue(const MyMoneyMoney& amount, bool forceUpdate)
 
     d->valueSet = true;
     d->m_value = amount;
-    const auto txt(amount.formatMoney(QString(), d->precision(AmountEdit::DisplayValue), false));
-    d->setValueText(txt);
+    d->updateWidgetText(AmountEdit::DisplayValue, amount);
 
     if (!hasMultipleCurrencies()) {
         setShares(amount);
@@ -669,9 +701,7 @@ void AmountEdit::setShares(const MyMoneyMoney& amount)
     Q_D(AmountEdit);
     d->sharesSet = !d->valueSet;
     d->m_shares = amount;
-
-    const auto txt(amount.formatMoney(QString(), d->precision(AmountEdit::DisplayShares), false));
-    d->setSharesText(txt);
+    d->updateWidgetText(AmountEdit::DisplayShares, amount);
 
     if (!d->m_shares.isZero()) {
         d->m_initialExchangeRate = d->m_value / d->m_shares;
@@ -698,6 +728,7 @@ void AmountEdit::theTextChanged(const QString & theText)
     QString nsign, psign;
     nsign = locale.negativeSign();
     psign = locale.positiveSign();
+    d->m_lastChangeWasRemove = false;
 
     auto i = 0;
     if (isEnabled()) {
@@ -717,6 +748,7 @@ void AmountEdit::theTextChanged(const QString & theText)
                 // adjust value or shares depending on state
                 // by using the initialExchangeRate
                 if (d->m_state == AmountEdit::DisplayValue) {
+                    d->m_lastChangeWasRemove = d->m_valueText.length() > l_text.length();
                     d->m_valueText = l_text;
                     MyMoneyMoney amount(l_text);
                     d->adjustToPrecision(AmountEdit::DisplayValue, amount);
@@ -724,6 +756,7 @@ void AmountEdit::theTextChanged(const QString & theText)
                     d->m_sharesText = amount.formatMoney(QString(), d->precision(AmountEdit::DisplayShares), false);
                     d->m_lastChanged = ValueChanged;
                 } else {
+                    d->m_lastChangeWasRemove = d->m_sharesText.length() > l_text.length();
                     d->m_sharesText = l_text;
                     MyMoneyMoney amount(l_text);
                     d->adjustToPrecision(AmountEdit::DisplayShares, amount);
