@@ -6,7 +6,7 @@
 #ifndef AMOUNTVALIDATOR_H
 #define AMOUNTVALIDATOR_H
 
-#include "kmm_widgets_export.h"
+#include "kmm_base_widgets_export.h"
 
 // ----------------------------------------------------------------------------
 // QT Includes
@@ -26,7 +26,7 @@
   *
   * @author Thomas Baumgart
   */
-class AmountValidator : public QDoubleValidator
+class KMM_BASE_WIDGETS_EXPORT AmountValidator : public QDoubleValidator
 {
     Q_OBJECT
 
@@ -34,6 +34,8 @@ public:
     explicit AmountValidator(QObject * parent);
     explicit AmountValidator(double bottom, double top, int decimals,
                              QObject * parent);
+
+    virtual QValidator::State validate(QString& input, int& pos) const override;
 };
 
 #endif
