@@ -2,6 +2,7 @@
     SPDX-FileCopyrightText: 2006 Darren Gould <darren_gould@gmx.de>
     SPDX-FileCopyrightText: 2009-2014 Alvaro Soliverez <asoliverez@gmail.com>
     SPDX-FileCopyrightText: 2017-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -19,7 +20,8 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "accountsviewproxymodel.h"
+#include "accountsproxymodel.h"
+#include "accountsmodel.h"
 
 class MyMoneyAccount;
 class MyMoneyBudget;
@@ -33,7 +35,7 @@ class MyMoneyMoney;
   * @author Cristian Oneț
   */
 class BudgetViewProxyModelPrivate;
-class KMM_WIDGETS_EXPORT BudgetViewProxyModel : public AccountsViewProxyModel
+class KMM_WIDGETS_EXPORT BudgetViewProxyModel : public AccountsProxyModel
 {
     Q_OBJECT
     Q_DISABLE_COPY(BudgetViewProxyModel)
@@ -42,10 +44,11 @@ public:
     explicit BudgetViewProxyModel(QObject *parent = nullptr);
     ~BudgetViewProxyModel() override;
 
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    virtual QVariant data(const QModelIndex &idx, int role = Qt::DisplayRole) const override;
+    Qt::ItemFlags flags(const QModelIndex &idx) const override;
 
     void setBudget(const MyMoneyBudget& budget);
+    void setColorScheme(AccountsModel::ColorScheme scheme, const QColor& color);
 
 Q_SIGNALS:
     /**
@@ -56,6 +59,7 @@ Q_SIGNALS:
 protected:
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
     MyMoneyMoney accountBalance(const QString &accountId) const;
+    MyMoneyMoney accountBalance(const QModelIndex& idx) const;
     MyMoneyMoney accountValue(const MyMoneyAccount &account, const MyMoneyMoney &balance) const;
     MyMoneyMoney computeTotalValue(const QModelIndex &source_index) const;
 
