@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2009-2010 Cristian One ț <onet.cristian@gmail.com>
+    SPDX-FileCopyrightText: 2009-2010 Cristian Oneț <onet.cristian@gmail.com>
     SPDX-FileCopyrightText: 2009-2010 Alvaro Soliverez <asoliverez@gmail.com>
     SPDX-FileCopyrightText: 2011-2017 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
@@ -9,6 +9,8 @@
 #ifndef KMYMONEYOCCURRENCECOMBO_H
 #define KMYMONEYOCCURRENCECOMBO_H
 
+#include "kmm_base_widgets_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -32,7 +34,7 @@ enum class Occurrence;
  *
  * @author Colin Wright
  */
-class KMM_WIDGETS_EXPORT KMyMoneyOccurrenceCombo : public KMyMoneyGeneralCombo
+class KMM_BASE_WIDGETS_EXPORT KMyMoneyOccurrenceCombo : public KMyMoneyGeneralCombo
 {
     Q_OBJECT
     Q_DISABLE_COPY(KMyMoneyOccurrenceCombo)
