@@ -7,6 +7,7 @@
 #ifndef KPRICETREEITEM_H
 #define KPRICETREEITEM_H
 
+#include "kmm_widgets_export.h"
 
 // ----------------------------------------------------------------------------
 // QT Includes
@@ -21,7 +22,7 @@
 // Project Includes
 
 
-class KPriceTreeItem : public QTreeWidgetItem
+class KMM_WIDGETS_EXPORT KPriceTreeItem : public QTreeWidgetItem
 {
 public:
     explicit KPriceTreeItem(QTreeWidget* parent);
@@ -30,10 +31,10 @@ public:
 
     enum PriceItemDataRole {
         ScheduleIdRole = Qt::UserRole,
-        OrderRole = Qt::UserRole + 1
+        OrderRole = Qt::UserRole + 1,
     };
 
-    enum ePriceColumns { ePriceCommodity = 0, ePriceStockName, ePriceCurrency, ePriceDate, ePricePrice, ePriceSource };
+    enum ePriceColumns { ePriceCommodity = 0, ePriceStockName, ePriceCurrency, ePriceDate, ePricePrice, ePriceSource, };
 
 };
 
