@@ -15,7 +15,7 @@ class KMM_WIDGETS_EXPORT KTreeWidgetFilterLineWidget : public KTreeWidgetSearchL
     Q_OBJECT
 
 public:
-    explicit KTreeWidgetFilterLineWidget(QWidget* parent = nullptr, QTreeWidget *treeWidget = 0);
+    explicit KTreeWidgetFilterLineWidget(QWidget* parent = nullptr, QTreeWidget* treeWidget = nullptr);
 
 protected Q_SLOTS:
     /**
