@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2013-2015 Christian Dávid <christian-david@web.de>
+    SPDX-FileCopyrightText: 2024 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -13,33 +14,36 @@
 ibanValidator::ibanValidator(QObject* parent)
     : QValidator(parent)
 {
-
 }
 
-QValidator::State ibanValidator::validate(QString& string, int&) const
+QValidator::State ibanValidator::validate(QString& input, int& pos) const
 {
-    // Check country code and set it uppercase
-    if (string.length() >= 1) {
-        fixup(string);
-        if (!string.at(0).isLetter())
+    // Check country code and convert it to uppercase (see ibanBic::ibanToPaperformat)
+    if (input.length() >= 1) {
+        fixup(input);
+        // if fixup took away characters, we might need to adjust the cursor pos
+        if (pos > input.length()) {
+            pos = input.length();
+        }
+        // check if fixup inserted a blank and bump the cursor pos if so
+        if ((pos > 1) && (input.at(pos - 1) == QLatin1Char(' '))) {
+            ++pos;
+        }
+        if (!input.at(0).isLetter())
             return Invalid;
-        if (string.at(0).isLower())
-            string[0] = string.at(0).toUpper();
     }
 
-    if (string.length() >= 2) {
-        if (!string.at(1).isLetterOrNumber())
+    if (input.length() >= 2) {
+        if (!input.at(1).isLetter())
             return Invalid;
-        if (string.at(1).isLower())
-            string[1] = string.at(1).toUpper();
     }
 
     // Check rest of the iban
-    int characterCount = qMin(string.length(), 2);
-    for (int i = 2; i < string.length(); ++i) {
-        if (string.at(i).isLetterOrNumber()) {
+    int characterCount = qMin(input.length(), 2);
+    for (int i = 2; i < input.length(); ++i) {
+        if (input.at(i).isLetterOrNumber()) {
             ++characterCount;
-        } else if (!string.at(i).isSpace()) {
+        } else if (!input.at(i).isSpace()) {
             return Invalid;
         }
     }
@@ -66,7 +70,7 @@ QPair< eWidgets::ValidationFeedback::MessageType, QString > ibanValidator::valid
     return QPair< eWidgets::ValidationFeedback::MessageType, QString >(eWidgets::ValidationFeedback::MessageType::None, QString());
 }
 
-void ibanValidator::fixup(QString& string) const
+void ibanValidator::fixup(QString& input) const
 {
-    string = payeeIdentifiers::ibanBic::ibanToPaperformat(string);
+    input = payeeIdentifiers::ibanBic::ibanToPaperformat(input);
 }
