@@ -7,6 +7,8 @@
 #ifndef TRANSACTIONSORTOPTIONIMPL_H
 #define TRANSACTIONSORTOPTIONIMPL_H
 
+#include "kmm_base_widgets_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -27,13 +29,13 @@ enum class SortField;
 
 class QListWidget;
 class QListWidgetItem;
-class TransactionSortOption : public QWidget
+class KMM_BASE_WIDGETS_EXPORT TransactionSortOption : public QWidget
 {
     Q_OBJECT
     Q_DISABLE_COPY(TransactionSortOption)
 
 public:
-    explicit TransactionSortOption(QWidget *parent);
+    explicit TransactionSortOption(QWidget* parent);
     ~TransactionSortOption();
     QString settings() const;
 
@@ -41,7 +43,7 @@ public Q_SLOTS:
     void setSettings(const QString& settings);
 
 protected:
-    QListWidgetItem * addEntry(QListWidget * p, QListWidgetItem * after, int idx);
+    QListWidgetItem* addEntry(QListWidget* p, QListWidgetItem* after, int idx);
     void setDirectionIcon(QListWidgetItem* item);
 
 protected Q_SLOTS:
@@ -58,7 +60,7 @@ Q_SIGNALS:
 private:
     static eWidgets::SortField textToSortOrder(const QString& text);
     static QString sortOrderToText(eWidgets::SortField idx);
-    Ui::TransactionSortOption *ui;
+    Ui::TransactionSortOption* ui;
 };
 
 #endif /* TRANSACTIONSORTOPTIONIMPL_H */
