@@ -7,6 +7,8 @@
 #ifndef KMYMONEYWIZARDPAGE_P_H
 #define KMYMONEYWIZARDPAGE_P_H
 
+#include "kmm_wizard_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -29,7 +31,7 @@ class KMandatoryFieldGroup;
   * derived from QObject directly.
   */
 
-class KMyMoneyWizardPagePrivate : public QObject
+class KMM_WIZARD_EXPORT KMyMoneyWizardPagePrivate : public QObject
 {
     Q_OBJECT
     Q_DISABLE_COPY(KMyMoneyWizardPagePrivate)
@@ -49,7 +51,7 @@ public:
 
     void emitCompleteStateChanged()
     {
-        emit completeStateChanged();
+        Q_EMIT completeStateChanged();
     }
 
     uint                  m_step;
