@@ -24,9 +24,8 @@ class MyMoneyAccount;
 namespace NewAccountWizard
 {
 class Wizard;
-class HierarchyFilterProxyModel;
-
 class HierarchyPagePrivate;
+
 class HierarchyPage : public QWidget, public WizardPage<Wizard>
 {
     Q_OBJECT
@@ -39,8 +38,7 @@ public:
     void enterPage() override;
     KMyMoneyWizardPage* nextPage() const override;
     QWidget* initialFocusWidget() const override;
-    const MyMoneyAccount& parentAccount();
-    void setParentAccount(const QString& id);
+    MyMoneyAccount parentAccount() const;
 
     bool isComplete() const override;
 
