@@ -103,9 +103,11 @@ bool KNewLoanWizard::validateCurrentPage()
         if (field("thisYearPaymentButton").toBool()
                 && !field("loanAmountEditValid").toBool()) {
             dontLeavePage = true;
-            KMessageBox::error(0, i18n("You selected, that payments have already been made towards this loan. "
-                                       "This requires you to enter the loan amount exactly as found on your "
-                                       "last statement."), i18n("Calculation error"));
+            KMessageBox::error(nullptr,
+                               i18n("You selected, that payments have already been made towards this loan. "
+                                    "This requires you to enter the loan amount exactly as found on your "
+                                    "last statement."),
+                               i18n("Calculation error"));
         } else
             d->updateLoanAmount();
 
@@ -114,7 +116,7 @@ bool KNewLoanWizard::validateCurrentPage()
         if (!field("loanAmountEditValid").toBool()
                 && !field("interestRateEditValid").toBool()) {
             dontLeavePage = true;
-            KMessageBox::error(0, ks.subs(i18n("interest rate")).toString(), i18n("Calculation error"));
+            KMessageBox::error(nullptr, ks.subs(i18n("interest rate")).toString(), i18n("Calculation error"));
         } else
             d->updateInterestRate();
 
@@ -123,7 +125,7 @@ bool KNewLoanWizard::validateCurrentPage()
                 || !field("interestRateEditValid").toBool())
                 && field("durationValueEdit").toInt() == 0) {
             dontLeavePage = true;
-            KMessageBox::error(0, ks.subs(i18n("term")).toString(), i18n("Calculation error"));
+            KMessageBox::error(nullptr, ks.subs(i18n("term")).toString(), i18n("Calculation error"));
         } else
             d->updateDuration();
 
@@ -133,7 +135,7 @@ bool KNewLoanWizard::validateCurrentPage()
                 || field("durationValueEdit").toInt() == 0)
                 && !field("paymentEditValid").toBool()) {
             dontLeavePage = true;
-            KMessageBox::error(0, ks.subs(i18n("principal and interest")).toString(), i18n("Calculation error"));
+            KMessageBox::error(nullptr, ks.subs(i18n("principal and interest")).toString(), i18n("Calculation error"));
         } else
             d->updatePayment();
 
