@@ -166,6 +166,7 @@ case "$ci_distro" in
                     "cmake(${kf}Config)"
                     "cmake(${kf}Contacts)"
                     "cmake(${kf}CoreAddons)"
+                    "cmake(${kf}Crash)"
                     "cmake(${kf}DocTools)"
                     "cmake(${kf}Holidays)"
                     "cmake(${kf}I18n)"
@@ -211,6 +212,7 @@ case "$ci_distro" in
                     "cmake(${qt}Concurrent)"
                     "cmake(${qt}Core5Compat)"
                     "cmake(${kf}ConfigWidgets)"
+                    "cmake(${kf}Crash)"
                     "cmake(${kf}NewStuffCore)"
                     "cmake(${kf}Service)"
                     "cmake(${kf}XmlGui)"
@@ -246,6 +248,7 @@ case "$ci_distro" in
                     "$prefix(cmake:${kf}Completion)"
                     "$prefix(cmake:${kf}Config)"
                     "$prefix(cmake:${kf}CoreAddons)"
+                    "$prefix(cmake:${kf}Crash)"
                     "$prefix(cmake:${kf}I18n)"
                     "$prefix(cmake:${kf}IconThemes)"
                     "$prefix(cmake:${kf}KIO)"
